# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalculatedBillUseRequest(Model):
    """Defines how use is calculated for a calculated bill distribution.

    :param readings_channel_id: Use monthly channel data readings to calculate
     bill use <span class='property-internal'>Required (defined)</span>
    :type readings_channel_id: int
    :param fixed_amount:
    :type fixed_amount: ~energycap.sdk.models.FixedUseRequest
    :param copy_use_from_meter:
    :type copy_use_from_meter: ~energycap.sdk.models.CopyMeterRequest
    :param use_calculation:
    :type use_calculation: ~energycap.sdk.models.CalculationRequest
    :param calendarized_use_calculation:
    :type calendarized_use_calculation:
     ~energycap.sdk.models.CalendarizedCalculationRequest
    """

    _attribute_map = {
        'readings_channel_id': {'key': 'readingsChannelId', 'type': 'int'},
        'fixed_amount': {'key': 'fixedAmount', 'type': 'FixedUseRequest'},
        'copy_use_from_meter': {'key': 'copyUseFromMeter', 'type': 'CopyMeterRequest'},
        'use_calculation': {'key': 'useCalculation', 'type': 'CalculationRequest'},
        'calendarized_use_calculation': {'key': 'calendarizedUseCalculation', 'type': 'CalendarizedCalculationRequest'},
    }

    def __init__(self, *, readings_channel_id: int=None, fixed_amount=None, copy_use_from_meter=None, use_calculation=None, calendarized_use_calculation=None, **kwargs) -> None:
        super(CalculatedBillUseRequest, self).__init__(**kwargs)
        self.readings_channel_id = readings_channel_id
        self.fixed_amount = fixed_amount
        self.copy_use_from_meter = copy_use_from_meter
        self.use_calculation = use_calculation
        self.calendarized_use_calculation = calendarized_use_calculation



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarPlaceLinkRequest(Model):
    """EnergyStarPlaceLinkRequest.

    :param pm_property_id: The Portfolio Manager property identifier.  Set to
     null to unlink place. <span class='property-internal'>Required
     (defined)</span>
    :type pm_property_id: long
    :param meters: List of meter links for this place
     If PmPropertyId is null to unlink the place then Meters should null.
     All meters under the place will be unlinked automatically. <span
     class='property-internal'>Required (defined)</span>
    :type meters: list[~energycap.sdk.models.EnergyStarMeterLinkRequest]
    """

    _attribute_map = {
        'pm_property_id': {'key': 'pmPropertyId', 'type': 'long'},
        'meters': {'key': 'meters', 'type': '[EnergyStarMeterLinkRequest]'},
    }

    def __init__(self, **kwargs):
        super(EnergyStarPlaceLinkRequest, self).__init__(**kwargs)
        self.pm_property_id = kwargs.get('pm_property_id', None)
        self.meters = kwargs.get('meters', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DataTypeResponse(Model):
    """DataTypeResponse.

    :param data_type_id:  <span class='property-internal'>Required
     (defined)</span>
    :type data_type_id: int
    :param data_type_code:  <span class='property-internal'>Required
     (defined)</span>
    :type data_type_code: str
    :param data_type_info:  <span class='property-internal'>Required
     (defined)</span>
    :type data_type_info: str
    """

    _attribute_map = {
        'data_type_id': {'key': 'dataTypeId', 'type': 'int'},
        'data_type_code': {'key': 'dataTypeCode', 'type': 'str'},
        'data_type_info': {'key': 'dataTypeInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(DataTypeResponse, self).__init__(**kwargs)
        self.data_type_id = kwargs.get('data_type_id', None)
        self.data_type_code = kwargs.get('data_type_code', None)
        self.data_type_info = kwargs.get('data_type_info', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebackTaskResponse(Model):
    """ChargebackTaskResponse.

    :param number_of_bills_created: The number of bills created by the task
    :type number_of_bills_created: int
    :param number_of_failed_versions: The number of chargeback versions that
     failed to run within the task
    :type number_of_failed_versions: int
    :param task_id: Identifier for the task
    :type task_id: int
    :param workflow:
    :type workflow: ~energycap.sdk.models.ChargebackWorkflowStepChild
    :param task_begin: Begin date when the task started
    :type task_begin: datetime
    :param task_end: End date when the task ended
    :type task_end: datetime
    :param user:
    :type user: ~energycap.sdk.models.UserChild
    :param billing_period: The billing period the task was run for
    :type billing_period: int
    :param batch:
    :type batch: ~energycap.sdk.models.BatchChild
    :param settings: The task's settings
    :type settings: object
    :param comment: User comments on the task
    :type comment: str
    :param status: Current status of the task
    :type status: str
    :param chargeback_type: The chargeback type.  Either "Split" or
     "Calculation"
    :type chargeback_type: str
    :param reversed_by:
    :type reversed_by: ~energycap.sdk.models.UserChild
    :param reversed_date: The date when all bills generated by the task were
     voided or deleted
    :type reversed_date: datetime
    :param number_of_analyzing_bills: The number of bills that are currently
     analyzing within the task
    :type number_of_analyzing_bills: int
    :param number_of_unresolved_flags: The number of unresolved flags on bills
     within the task
    :type number_of_unresolved_flags: int
    """

    _attribute_map = {
        'number_of_bills_created': {'key': 'numberOfBillsCreated', 'type': 'int'},
        'number_of_failed_versions': {'key': 'numberOfFailedVersions', 'type': 'int'},
        'task_id': {'key': 'taskId', 'type': 'int'},
        'workflow': {'key': 'workflow', 'type': 'ChargebackWorkflowStepChild'},
        'task_begin': {'key': 'taskBegin', 'type': 'iso-8601'},
        'task_end': {'key': 'taskEnd', 'type': 'iso-8601'},
        'user': {'key': 'user', 'type': 'UserChild'},
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'batch': {'key': 'batch', 'type': 'BatchChild'},
        'settings': {'key': 'settings', 'type': 'object'},
        'comment': {'key': 'comment', 'type': 'str'},
        'status': {'key': 'status', 'type': 'str'},
        'chargeback_type': {'key': 'chargebackType', 'type': 'str'},
        'reversed_by': {'key': 'reversedBy', 'type': 'UserChild'},
        'reversed_date': {'key': 'reversedDate', 'type': 'iso-8601'},
        'number_of_analyzing_bills': {'key': 'numberOfAnalyzingBills', 'type': 'int'},
        'number_of_unresolved_flags': {'key': 'numberOfUnresolvedFlags', 'type': 'int'},
    }

    def __init__(self, *, number_of_bills_created: int=None, number_of_failed_versions: int=None, task_id: int=None, workflow=None, task_begin=None, task_end=None, user=None, billing_period: int=None, batch=None, settings=None, comment: str=None, status: str=None, chargeback_type: str=None, reversed_by=None, reversed_date=None, number_of_analyzing_bills: int=None, number_of_unresolved_flags: int=None, **kwargs) -> None:
        super(ChargebackTaskResponse, self).__init__(**kwargs)
        self.number_of_bills_created = number_of_bills_created
        self.number_of_failed_versions = number_of_failed_versions
        self.task_id = task_id
        self.workflow = workflow
        self.task_begin = task_begin
        self.task_end = task_end
        self.user = user
        self.billing_period = billing_period
        self.batch = batch
        self.settings = settings
        self.comment = comment
        self.status = status
        self.chargeback_type = chargeback_type
        self.reversed_by = reversed_by
        self.reversed_date = reversed_date
        self.number_of_analyzing_bills = number_of_analyzing_bills
        self.number_of_unresolved_flags = number_of_unresolved_flags



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PrimaryUseCreate(Model):
    """PrimaryUseCreate.

    All required parameters must be populated in order to send to Azure.

    :param primary_use_code: Required. The Primary Use Code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type primary_use_code: str
    :param primary_use_info: Required. The Primary Use Info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type primary_use_info: str
    :param primary_use_type: Required. The Primary Use Type. Possible value
     include: "place" and "meter" <span
     class='property-internal'>Required</span> <span
     class='property-internal'>One of place, meter </span>
    :type primary_use_type: str
    """

    _validation = {
        'primary_use_code': {'required': True, 'max_length': 64, 'min_length': 0},
        'primary_use_info': {'required': True, 'max_length': 64, 'min_length': 0},
        'primary_use_type': {'required': True},
    }

    _attribute_map = {
        'primary_use_code': {'key': 'primaryUseCode', 'type': 'str'},
        'primary_use_info': {'key': 'primaryUseInfo', 'type': 'str'},
        'primary_use_type': {'key': 'primaryUseType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(PrimaryUseCreate, self).__init__(**kwargs)
        self.primary_use_code = kwargs.get('primary_use_code', None)
        self.primary_use_info = kwargs.get('primary_use_info', None)
        self.primary_use_type = kwargs.get('primary_use_type', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FixedUseRequest(Model):
    """FixedUseRequest.

    All required parameters must be populated in order to send to Azure.

    :param fixed_use_amount: Required. Fixed use amount <span
     class='property-internal'>Required</span> <span class='property-info'>Max
     scale of 6</span>
    :type fixed_use_amount: float
    :param unit_id: Required. Unit to which use is applied <span
     class='property-internal'>Required</span>
    :type unit_id: int
    """

    _validation = {
        'fixed_use_amount': {'required': True},
        'unit_id': {'required': True},
    }

    _attribute_map = {
        'fixed_use_amount': {'key': 'fixedUseAmount', 'type': 'float'},
        'unit_id': {'key': 'unitId', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(FixedUseRequest, self).__init__(**kwargs)
        self.fixed_use_amount = kwargs.get('fixed_use_amount', None)
        self.unit_id = kwargs.get('unit_id', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillSplitPlaceSizeChild(Model):
    """BillSplitPlaceSizeChild.

    :param place_size_id:
    :type place_size_id: int
    :param begin_date:
    :type begin_date: datetime
    :param end_date:
    :type end_date: datetime
    :param value:
    :type value: float
    :param unit:
    :type unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'place_size_id': {'key': 'placeSizeId', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'value': {'key': 'value', 'type': 'float'},
        'unit': {'key': 'unit', 'type': 'UnitChild'},
    }

    def __init__(self, **kwargs):
        super(BillSplitPlaceSizeChild, self).__init__(**kwargs)
        self.place_size_id = kwargs.get('place_size_id', None)
        self.begin_date = kwargs.get('begin_date', None)
        self.end_date = kwargs.get('end_date', None)
        self.value = kwargs.get('value', None)
        self.unit = kwargs.get('unit', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class QuickFilter(Model):
    """QuickFilter.

    All required parameters must be populated in order to send to Azure.

    :param caption: Required.  <span class='property-internal'>Required</span>
    :type caption: str
    :param operator: Required.  <span
     class='property-internal'>Required</span>
    :type operator: str
    :param value: Required.  <span class='property-internal'>Required</span>
    :type value: str
    """

    _validation = {
        'caption': {'required': True},
        'operator': {'required': True},
        'value': {'required': True},
    }

    _attribute_map = {
        'caption': {'key': 'caption', 'type': 'str'},
        'operator': {'key': 'operator', 'type': 'str'},
        'value': {'key': 'value', 'type': 'str'},
    }

    def __init__(self, *, caption: str, operator: str, value: str, **kwargs) -> None:
        super(QuickFilter, self).__init__(**kwargs)
        self.caption = caption
        self.operator = operator
        self.value = value



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebackProcessorSettingsForSplits(Model):
    """ChargebackProcessorSettingsForSplits.

    :param note: Optional note/comment <span class='property-internal'>Must be
     between 0 and 255 characters</span>
    :type note: str
    :param batch_settings:
    :type batch_settings: ~energycap.sdk.models.BatchCreate
    """

    _validation = {
        'note': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'note': {'key': 'note', 'type': 'str'},
        'batch_settings': {'key': 'batchSettings', 'type': 'BatchCreate'},
    }

    def __init__(self, *, note: str=None, batch_settings=None, **kwargs) -> None:
        super(ChargebackProcessorSettingsForSplits, self).__init__(**kwargs)
        self.note = note
        self.batch_settings = batch_settings



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TimeZoneResponse(Model):
    """TimeZoneResponse.

    :param time_zone_id: The time zone id
    :type time_zone_id: int
    :param time_zone_code: The time zone code
    :type time_zone_code: str
    :param time_zone_info: The time zone info
    :type time_zone_info: str
    :param gmt_offset: The time zone gmt offset
    :type gmt_offset: float
    :param daylight_savings_observed: Indicates if the time zone observes
     daylight savings time or not
    :type daylight_savings_observed: bool
    """

    _attribute_map = {
        'time_zone_id': {'key': 'timeZoneId', 'type': 'int'},
        'time_zone_code': {'key': 'timeZoneCode', 'type': 'str'},
        'time_zone_info': {'key': 'timeZoneInfo', 'type': 'str'},
        'gmt_offset': {'key': 'gmtOffset', 'type': 'float'},
        'daylight_savings_observed': {'key': 'daylightSavingsObserved', 'type': 'bool'},
    }

    def __init__(self, *, time_zone_id: int=None, time_zone_code: str=None, time_zone_info: str=None, gmt_offset: float=None, daylight_savings_observed: bool=None, **kwargs) -> None:
        super(TimeZoneResponse, self).__init__(**kwargs)
        self.time_zone_id = time_zone_id
        self.time_zone_code = time_zone_code
        self.time_zone_info = time_zone_info
        self.gmt_offset = gmt_offset
        self.daylight_savings_observed = daylight_savings_observed



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SystemUserRoleResponse(Model):
    """SystemUserRoleResponse.

    :param system_user_role_id: Identifier for the system user role
    :type system_user_role_id: int
    :param system_user_role_name: Name of the system user role
    :type system_user_role_name: str
    :param description: Description of the system user role
    :type description: str
    :param users_assigned_count: Number of users currently assigned to the
     system user role
    :type users_assigned_count: int
    :param permissions:
    :type permissions: ~energycap.sdk.models.Permissions
    :param read_only: Indicates the system user role that cannot be modified
     These roles can be hidden using the SetUserRoleHidden API
    :type read_only: bool
    :param hidden: Hidden status of the system user role
     Roles Manage permission is required to access hidden roles
    :type hidden: bool
    """

    _attribute_map = {
        'system_user_role_id': {'key': 'systemUserRoleId', 'type': 'int'},
        'system_user_role_name': {'key': 'systemUserRoleName', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'users_assigned_count': {'key': 'usersAssignedCount', 'type': 'int'},
        'permissions': {'key': 'permissions', 'type': 'Permissions'},
        'read_only': {'key': 'readOnly', 'type': 'bool'},
        'hidden': {'key': 'hidden', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(SystemUserRoleResponse, self).__init__(**kwargs)
        self.system_user_role_id = kwargs.get('system_user_role_id', None)
        self.system_user_role_name = kwargs.get('system_user_role_name', None)
        self.description = kwargs.get('description', None)
        self.users_assigned_count = kwargs.get('users_assigned_count', None)
        self.permissions = kwargs.get('permissions', None)
        self.read_only = kwargs.get('read_only', None)
        self.hidden = kwargs.get('hidden', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FormTemplateRequest(Model):
    """FormTemplateRequest.

    All required parameters must be populated in order to send to Azure.

    :param template_id: Required. The identifier for the template being
     assigned <span class='property-internal'>Required</span> <span
     class='property-internal'>Required</span>
    :type template_id: int
    :param begin_date: Required. The begin date of the template assignment
     <span class='property-internal'>Required</span> <span
     class='property-internal'>Required</span>
    :type begin_date: datetime
    """

    _validation = {
        'template_id': {'required': True},
        'begin_date': {'required': True},
    }

    _attribute_map = {
        'template_id': {'key': 'templateId', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(FormTemplateRequest, self).__init__(**kwargs)
        self.template_id = kwargs.get('template_id', None)
        self.begin_date = kwargs.get('begin_date', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UDFSelectValueUpdate(Model):
    """UDFSelectValueUpdate.

    All required parameters must be populated in order to send to Azure.

    :param udf_select_value_id: The UDF select value identifier. When creating
     a new option, assign null to this property. <span
     class='property-internal'>Required (defined)</span>
    :type udf_select_value_id: int
    :param value: Required. The UDF select option's value <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type value: str
    """

    _validation = {
        'value': {'required': True, 'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'udf_select_value_id': {'key': 'udfSelectValueId', 'type': 'int'},
        'value': {'key': 'value', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(UDFSelectValueUpdate, self).__init__(**kwargs)
        self.udf_select_value_id = kwargs.get('udf_select_value_id', None)
        self.value = kwargs.get('value', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillActionExportHold(Model):
    """BillActionExportHold.

    :param ids:  <span class='property-internal'>Cannot be Empty</span> <span
     class='property-internal'>Required (defined)</span>
    :type ids: list[int]
    :param export_hold:  <span class='property-internal'>Required
     (defined)</span>
    :type export_hold: bool
    """

    _attribute_map = {
        'ids': {'key': 'ids', 'type': '[int]'},
        'export_hold': {'key': 'exportHold', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(BillActionExportHold, self).__init__(**kwargs)
        self.ids = kwargs.get('ids', None)
        self.export_hold = kwargs.get('export_hold', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AssignVersionsToStep(Model):
    """AssignVersionsToStep.

    :param calculate_bill_version_ids: List of calculated bill or bill split
     version IDs to assign to a chargeback workflow step <span
     class='property-internal'>Required (defined)</span>
    :type calculate_bill_version_ids: list[int]
    """

    _attribute_map = {
        'calculate_bill_version_ids': {'key': 'calculateBillVersionIds', 'type': '[int]'},
    }

    def __init__(self, *, calculate_bill_version_ids=None, **kwargs) -> None:
        super(AssignVersionsToStep, self).__init__(**kwargs)
        self.calculate_bill_version_ids = calculate_bill_version_ids



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class VendorResponse(Model):
    """VendorResponse.

    :param vendor_id: The vendor identifier
    :type vendor_id: int
    :param vendor_code: The vendor code
    :type vendor_code: str
    :param vendor_info: The vendor info
    :type vendor_info: str
    :param address:
    :type address: ~energycap.sdk.models.AddressChild
    :param edi_code: The vendor's edi code
    :type edi_code: str
    :param pay_days: The pay days
    :type pay_days: int
    :param created_by:
    :type created_by: ~energycap.sdk.models.UserChild
    :param created_date: The date and time the vendor was created
    :type created_date: datetime
    :param modified_by:
    :type modified_by: ~energycap.sdk.models.UserChild
    :param modified_date: The date and time of the most recent modification
    :type modified_date: datetime
    :param website: The vendor's website
    :type website: str
    :param rates: The vendor's rates
    :type rates: list[~energycap.sdk.models.RateChildResponse]
    :param vendor_description: A description of the vendor
    :type vendor_description: str
    """

    _attribute_map = {
        'vendor_id': {'key': 'vendorId', 'type': 'int'},
        'vendor_code': {'key': 'vendorCode', 'type': 'str'},
        'vendor_info': {'key': 'vendorInfo', 'type': 'str'},
        'address': {'key': 'address', 'type': 'AddressChild'},
        'edi_code': {'key': 'ediCode', 'type': 'str'},
        'pay_days': {'key': 'payDays', 'type': 'int'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'modified_by': {'key': 'modifiedBy', 'type': 'UserChild'},
        'modified_date': {'key': 'modifiedDate', 'type': 'iso-8601'},
        'website': {'key': 'website', 'type': 'str'},
        'rates': {'key': 'rates', 'type': '[RateChildResponse]'},
        'vendor_description': {'key': 'vendorDescription', 'type': 'str'},
    }

    def __init__(self, *, vendor_id: int=None, vendor_code: str=None, vendor_info: str=None, address=None, edi_code: str=None, pay_days: int=None, created_by=None, created_date=None, modified_by=None, modified_date=None, website: str=None, rates=None, vendor_description: str=None, **kwargs) -> None:
        super(VendorResponse, self).__init__(**kwargs)
        self.vendor_id = vendor_id
        self.vendor_code = vendor_code
        self.vendor_info = vendor_info
        self.address = address
        self.edi_code = edi_code
        self.pay_days = pay_days
        self.created_by = created_by
        self.created_date = created_date
        self.modified_by = modified_by
        self.modified_date = modified_date
        self.website = website
        self.rates = rates
        self.vendor_description = vendor_description



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportGroupRequest(Model):
    """ReportGroupRequest.

    :param report_group_code:
    :type report_group_code: str
    :param report_group_info:
    :type report_group_info: str
    :param report_ids:
    :type report_ids: list[int]
    """

    _attribute_map = {
        'report_group_code': {'key': 'reportGroupCode', 'type': 'str'},
        'report_group_info': {'key': 'reportGroupInfo', 'type': 'str'},
        'report_ids': {'key': 'reportIds', 'type': '[int]'},
    }

    def __init__(self, *, report_group_code: str=None, report_group_info: str=None, report_ids=None, **kwargs) -> None:
        super(ReportGroupRequest, self).__init__(**kwargs)
        self.report_group_code = report_group_code
        self.report_group_info = report_group_info
        self.report_ids = report_ids



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportSubscriptionDayIndicatorChild(Model):
    """ReportSubscriptionDayIndicatorChild.

    :param day_indicator_value: Indicates when to send the report for the
     given schedule type
     Values may be:
     Daily: 0
     Weekly: Day of Week - 0 (Sunday) to 6 (Saturday)
     Monthly: Day of Month - 1 to 28
     Quarterly: Month in Quarter - 1, 2, or 3
    :type day_indicator_value: int
    :param day_indicator_info: Name of the day indicator
     Daily: None
     Weekly: One of Sunday to Saturday
     Monthly: One of 1 to 28
     Quarterly: 1st day of month 1 of calendar quarter, 1st day of month 2 of
     calendar quarter, 1st day of month 3 of calendar quarter
    :type day_indicator_info: str
    """

    _attribute_map = {
        'day_indicator_value': {'key': 'dayIndicatorValue', 'type': 'int'},
        'day_indicator_info': {'key': 'dayIndicatorInfo', 'type': 'str'},
    }

    def __init__(self, *, day_indicator_value: int=None, day_indicator_info: str=None, **kwargs) -> None:
        super(ReportSubscriptionDayIndicatorChild, self).__init__(**kwargs)
        self.day_indicator_value = day_indicator_value
        self.day_indicator_info = day_indicator_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserChildWithEmail(Model):
    """UserChildWithEmail.

    :param email: Email ID of the user
    :type email: str
    :param user_id: The user identifier
    :type user_id: int
    :param user_code: The user code
    :type user_code: str
    :param full_name: The user's full name
    :type full_name: str
    """

    _attribute_map = {
        'email': {'key': 'email', 'type': 'str'},
        'user_id': {'key': 'userId', 'type': 'int'},
        'user_code': {'key': 'userCode', 'type': 'str'},
        'full_name': {'key': 'fullName', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(UserChildWithEmail, self).__init__(**kwargs)
        self.email = kwargs.get('email', None)
        self.user_id = kwargs.get('user_id', None)
        self.user_code = kwargs.get('user_code', None)
        self.full_name = kwargs.get('full_name', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class VendorContractResponse(Model):
    """VendorContractResponse.

    :param contract_id: The contract identifier
    :type contract_id: int
    :param contract_code: The contract code
    :type contract_code: str
    :param contract_info: The contract info
    :type contract_info: str
    :param start_date: The start date of the contract
    :type start_date: datetime
    :param expiration_date: The expiration date of the contract
    :type expiration_date: datetime
    :param notes: Contract notes
    :type notes: str
    :param vendor:
    :type vendor: ~energycap.sdk.models.VendorChild
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param renewal_reminder_date: The date a reminder will be sent for the
     contract expiration
    :type renewal_reminder_date: datetime
    :param is_green_energy: Is this a Green Energy contract
    :type is_green_energy: bool
    """

    _attribute_map = {
        'contract_id': {'key': 'contractId', 'type': 'int'},
        'contract_code': {'key': 'contractCode', 'type': 'str'},
        'contract_info': {'key': 'contractInfo', 'type': 'str'},
        'start_date': {'key': 'startDate', 'type': 'iso-8601'},
        'expiration_date': {'key': 'expirationDate', 'type': 'iso-8601'},
        'notes': {'key': 'notes', 'type': 'str'},
        'vendor': {'key': 'vendor', 'type': 'VendorChild'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'renewal_reminder_date': {'key': 'renewalReminderDate', 'type': 'iso-8601'},
        'is_green_energy': {'key': 'isGreenEnergy', 'type': 'bool'},
    }

    def __init__(self, *, contract_id: int=None, contract_code: str=None, contract_info: str=None, start_date=None, expiration_date=None, notes: str=None, vendor=None, commodity=None, renewal_reminder_date=None, is_green_energy: bool=None, **kwargs) -> None:
        super(VendorContractResponse, self).__init__(**kwargs)
        self.contract_id = contract_id
        self.contract_code = contract_code
        self.contract_info = contract_info
        self.start_date = start_date
        self.expiration_date = expiration_date
        self.notes = notes
        self.vendor = vendor
        self.commodity = commodity
        self.renewal_reminder_date = renewal_reminder_date
        self.is_green_energy = is_green_energy



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebackWorkflowDigestSplitChild(Model):
    """ChargebackWorkflowDigestSplitChild.

    :param meter:
    :type meter: ~energycap.sdk.models.MeterChild
    :param current_period:
    :type current_period: ~energycap.sdk.models.BillingPeriodUseCostChild
    :param prior_period:
    :type prior_period: ~energycap.sdk.models.BillingPeriodUseCostDeltaChild
    :param prior_year:
    :type prior_year: ~energycap.sdk.models.BillingPeriodUseCostDeltaChild
    """

    _attribute_map = {
        'meter': {'key': 'meter', 'type': 'MeterChild'},
        'current_period': {'key': 'currentPeriod', 'type': 'BillingPeriodUseCostChild'},
        'prior_period': {'key': 'priorPeriod', 'type': 'BillingPeriodUseCostDeltaChild'},
        'prior_year': {'key': 'priorYear', 'type': 'BillingPeriodUseCostDeltaChild'},
    }

    def __init__(self, **kwargs):
        super(ChargebackWorkflowDigestSplitChild, self).__init__(**kwargs)
        self.meter = kwargs.get('meter', None)
        self.current_period = kwargs.get('current_period', None)
        self.prior_period = kwargs.get('prior_period', None)
        self.prior_year = kwargs.get('prior_year', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountRateRequest(Model):
    """AccountRateRequest.

    All required parameters must be populated in order to send to Azure.

    :param rate_id: Required. The identifier for the rate to assign to the
     accountMeter <span class='property-internal'>Required</span> <span
     class='property-internal'>Required</span>
    :type rate_id: int
    :param start_date: Required. The start date for the accountRate <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Required</span>
    :type start_date: datetime
    """

    _validation = {
        'rate_id': {'required': True},
        'start_date': {'required': True},
    }

    _attribute_map = {
        'rate_id': {'key': 'rateId', 'type': 'int'},
        'start_date': {'key': 'startDate', 'type': 'iso-8601'},
    }

    def __init__(self, *, rate_id: int, start_date, **kwargs) -> None:
        super(AccountRateRequest, self).__init__(**kwargs)
        self.rate_id = rate_id
        self.start_date = start_date



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarPlaceMetricsResponse(Model):
    """EnergyStarPlaceMetricsResponse.

    :param calendar_period: The year and month for the ENERGY STAR score
    :type calendar_period: int
    :param score: The ENERGY STAR score
    :type score: int
    :param date_received: The date the score was received
    :type date_received: datetime
    :param site_energy_use: The weather-normalized property energy use (kBtu)
    :type site_energy_use: float
    :param site_energy_use_intensity: The weather-normalized property energy
     use intensity (kBtu/ft²)
    :type site_energy_use_intensity: float
    :param national_median_score: The national median ENERGY STAR score for
     the same type of property
    :type national_median_score: int
    :param national_median_site_energy_use_intensity: The national median
     weather-normalized property energy use intensity (kBtu/ft²)
    :type national_median_site_energy_use_intensity: float
    :param pct_diff_national_median_site_energy_use_intensity: The percent
     difference in the property energy use intensity vs. the national median
    :type pct_diff_national_median_site_energy_use_intensity: float
    """

    _attribute_map = {
        'calendar_period': {'key': 'calendarPeriod', 'type': 'int'},
        'score': {'key': 'score', 'type': 'int'},
        'date_received': {'key': 'dateReceived', 'type': 'iso-8601'},
        'site_energy_use': {'key': 'siteEnergyUse', 'type': 'float'},
        'site_energy_use_intensity': {'key': 'siteEnergyUseIntensity', 'type': 'float'},
        'national_median_score': {'key': 'nationalMedianScore', 'type': 'int'},
        'national_median_site_energy_use_intensity': {'key': 'nationalMedianSiteEnergyUseIntensity', 'type': 'float'},
        'pct_diff_national_median_site_energy_use_intensity': {'key': 'pctDiffNationalMedianSiteEnergyUseIntensity', 'type': 'float'},
    }

    def __init__(self, *, calendar_period: int=None, score: int=None, date_received=None, site_energy_use: float=None, site_energy_use_intensity: float=None, national_median_score: int=None, national_median_site_energy_use_intensity: float=None, pct_diff_national_median_site_energy_use_intensity: float=None, **kwargs) -> None:
        super(EnergyStarPlaceMetricsResponse, self).__init__(**kwargs)
        self.calendar_period = calendar_period
        self.score = score
        self.date_received = date_received
        self.site_energy_use = site_energy_use
        self.site_energy_use_intensity = site_energy_use_intensity
        self.national_median_score = national_median_score
        self.national_median_site_energy_use_intensity = national_median_site_energy_use_intensity
        self.pct_diff_national_median_site_energy_use_intensity = pct_diff_national_median_site_energy_use_intensity



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillViewAddressChild(Model):
    """BillViewAddressChild.

    :param address_type_id: The address type identifier
    :type address_type_id: int
    :param line1: The line 1 of the address
    :type line1: str
    :param line2: The line 2 of the address
    :type line2: str
    :param line3: The line 2 of the address
    :type line3: str
    :param city: The city of the address
    :type city: str
    :param state: The state of the address
    :type state: str
    :param country: The country of the address
    :type country: str
    :param postal_code: The postal code of the address
    :type postal_code: str
    """

    _attribute_map = {
        'address_type_id': {'key': 'addressTypeId', 'type': 'int'},
        'line1': {'key': 'line1', 'type': 'str'},
        'line2': {'key': 'line2', 'type': 'str'},
        'line3': {'key': 'line3', 'type': 'str'},
        'city': {'key': 'city', 'type': 'str'},
        'state': {'key': 'state', 'type': 'str'},
        'country': {'key': 'country', 'type': 'str'},
        'postal_code': {'key': 'postalCode', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(BillViewAddressChild, self).__init__(**kwargs)
        self.address_type_id = kwargs.get('address_type_id', None)
        self.line1 = kwargs.get('line1', None)
        self.line2 = kwargs.get('line2', None)
        self.line3 = kwargs.get('line3', None)
        self.city = kwargs.get('city', None)
        self.state = kwargs.get('state', None)
        self.country = kwargs.get('country', None)
        self.postal_code = kwargs.get('postal_code', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AddressChild(Model):
    """AddressChild.

    :param address_type_id: The address type identifier
    :type address_type_id: int
    :param line1: The line 1 of the address <span
     class='property-internal'>Must be between 0 and 100 characters</span>
    :type line1: str
    :param line2: The line 2 of the address <span
     class='property-internal'>Must be between 0 and 100 characters</span>
    :type line2: str
    :param line3: The line 3 of the address <span
     class='property-internal'>Must be between 0 and 100 characters</span>.
     Default value: "Æ" .
    :type line3: str
    :param city: The city of the place <span class='property-internal'>Must be
     between 0 and 100 characters</span>
    :type city: str
    :param state: The state of the place <span class='property-internal'>Must
     be between 0 and 100 characters</span>
    :type state: str
    :param country: The country of the place <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type country: str
    :param postal_code: The postal code of the place <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type postal_code: str
    :param latitude: The latitude of the place
     Required when the country is not United States or Canada <span
     class='property-internal'>Must be between -90 and 90</span>
    :type latitude: float
    :param longitude: The longitude of the place
     Required when the country is not United States or Canada <span
     class='property-internal'>Must be between -180 and 180</span>
    :type longitude: float
    """

    _validation = {
        'line1': {'max_length': 100, 'min_length': 0},
        'line2': {'max_length': 100, 'min_length': 0},
        'line3': {'max_length': 100, 'min_length': 0},
        'city': {'max_length': 100, 'min_length': 0},
        'state': {'max_length': 100, 'min_length': 0},
        'country': {'max_length': 64, 'min_length': 0},
        'postal_code': {'max_length': 32, 'min_length': 0},
        'latitude': {'maximum': 90, 'minimum': -90},
        'longitude': {'maximum': 180, 'minimum': -180},
    }

    _attribute_map = {
        'address_type_id': {'key': 'addressTypeId', 'type': 'int'},
        'line1': {'key': 'line1', 'type': 'str'},
        'line2': {'key': 'line2', 'type': 'str'},
        'line3': {'key': 'line3', 'type': 'str'},
        'city': {'key': 'city', 'type': 'str'},
        'state': {'key': 'state', 'type': 'str'},
        'country': {'key': 'country', 'type': 'str'},
        'postal_code': {'key': 'postalCode', 'type': 'str'},
        'latitude': {'key': 'latitude', 'type': 'float'},
        'longitude': {'key': 'longitude', 'type': 'float'},
    }

    def __init__(self, *, address_type_id: int=None, line1: str=None, line2: str=None, line3: str="Æ", city: str=None, state: str=None, country: str=None, postal_code: str=None, latitude: float=None, longitude: float=None, **kwargs) -> None:
        super(AddressChild, self).__init__(**kwargs)
        self.address_type_id = address_type_id
        self.line1 = line1
        self.line2 = line2
        self.line3 = line3
        self.city = city
        self.state = state
        self.country = country
        self.postal_code = postal_code
        self.latitude = latitude
        self.longitude = longitude



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SavingsMeterBillDailyResponse(Model):
    """SavingsMeterBillDailyResponseDTO - This class is the DTO for a meter's
    bill's Cost Avoidance savings in daily format
    It provides the meter, bill, use unit, and then an array of daily savings
    values
    Each daily value contains date that represents this day, non-weather use,
    weather use, BATCC Cost, average daily unit cost,
    whether any of the four adjustments (special, area, weather, other) were
    performed
    and a list of messages generated by the Savings Processor for this day.

    :param meter_id: Unique meter identifier
    :type meter_id: int
    :param meter_code: Meter Code
    :type meter_code: str
    :param meter_info: Meter Name
    :type meter_info: str
    :param bill_id: Unique bill identifier
    :type bill_id: int
    :param period_name: Calendar Period Name (e.g. Jan)
    :type period_name: str
    :param calendar_period: Calendar period Number (e.g. 1)
    :type calendar_period: int
    :param calendar_year: Calendar year (e.g. 2019)
    :type calendar_year: int
    :param fiscal_period: Fiscal period number
    :type fiscal_period: int
    :param fiscal_year: Fiscal year
    :type fiscal_year: int
    :param native_use_unit:
    :type native_use_unit: ~energycap.sdk.models.UnitChild
    :param daily: Cost avoidance savings for this meter, day by day
    :type daily: list[~energycap.sdk.models.SavingsDailyData]
    """

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
        'bill_id': {'key': 'billId', 'type': 'int'},
        'period_name': {'key': 'periodName', 'type': 'str'},
        'calendar_period': {'key': 'calendarPeriod', 'type': 'int'},
        'calendar_year': {'key': 'calendarYear', 'type': 'int'},
        'fiscal_period': {'key': 'fiscalPeriod', 'type': 'int'},
        'fiscal_year': {'key': 'fiscalYear', 'type': 'int'},
        'native_use_unit': {'key': 'nativeUseUnit', 'type': 'UnitChild'},
        'daily': {'key': 'daily', 'type': '[SavingsDailyData]'},
    }

    def __init__(self, **kwargs):
        super(SavingsMeterBillDailyResponse, self).__init__(**kwargs)
        self.meter_id = kwargs.get('meter_id', None)
        self.meter_code = kwargs.get('meter_code', None)
        self.meter_info = kwargs.get('meter_info', None)
        self.bill_id = kwargs.get('bill_id', None)
        self.period_name = kwargs.get('period_name', None)
        self.calendar_period = kwargs.get('calendar_period', None)
        self.calendar_year = kwargs.get('calendar_year', None)
        self.fiscal_period = kwargs.get('fiscal_period', None)
        self.fiscal_year = kwargs.get('fiscal_year', None)
        self.native_use_unit = kwargs.get('native_use_unit', None)
        self.daily = kwargs.get('daily', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class OutlierSeverityChild(Model):
    """OutlierSeverityChild.

    :param outlier_severity: The integer that represents the severity of the
     outlier
     Values: 1, 2, 3, or 4
    :type outlier_severity: int
    :param outlier_severity_info: The information regarding the current
     outlier severity
     Values: 1 = Severe, 2 = High, 3 = Moderate, 4 = Cannot be determined
     Severe - Actual value is 1, standard deviation > 3.0 on the high side or >
     5.0 on the low side
     High - Actual value is 2, standard deviation > 2.0 high and > 4.0 low
     Moderate - Actual value is 3, standard deviation > 1.5 high and > 3.0 low
     Not Classified - It is not one of Severe, High, Low or the model could not
     be determined
    :type outlier_severity_info: str
    """

    _attribute_map = {
        'outlier_severity': {'key': 'outlierSeverity', 'type': 'int'},
        'outlier_severity_info': {'key': 'outlierSeverityInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(OutlierSeverityChild, self).__init__(**kwargs)
        self.outlier_severity = kwargs.get('outlier_severity', None)
        self.outlier_severity_info = kwargs.get('outlier_severity_info', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UpsertAggregateMeterRequest(Model):
    """UpsertAggregateMeterRequest.

    All required parameters must be populated in order to send to Azure.

    :param aggregate_meter_id: Aggregation Meter Identifier
     If AggregateMeterId is null: a new aggregate meter and version is always
     created
     If AggregateMeterId is not null: it must exist and only associated with 1
     account otherwise error
     If AggregateMeterId exists: we will always update the Aggregate's
     MeterInfo and AccountInfo
     If AggregateMeterId exists and no version exists on the same account and
     meter with the specified billing period: a new version is created
     If AggregateMeterId exists and a version exists on the same account and
     meter with the specified billing period: the version is updated <span
     class='property-internal'>Required (defined)</span>
    :type aggregate_meter_id: int
    :param begin_period: Required. Begin period for the version in the format
     YYYYMM <span class='property-internal'>Required</span>
    :type begin_period: int
    :param source_meter_ids: Required. Meters to aggregate
     All meters must match the commodity of the aggregate meter
     All meters must be on the place the aggregate is created
     All meters should be hidden <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Cannot be Empty</span>
    :type source_meter_ids: list[int]
    :param commodity_id: Required. The identifier for the aggregate meter's
     commodity <span class='property-internal'>Required</span>
    :type commodity_id: int
    :param aggregate_meter_info: Required. The aggregate meter info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type aggregate_meter_info: str
    """

    _validation = {
        'begin_period': {'required': True},
        'source_meter_ids': {'required': True},
        'commodity_id': {'required': True},
        'aggregate_meter_info': {'required': True, 'max_length': 50, 'min_length': 0},
    }

    _attribute_map = {
        'aggregate_meter_id': {'key': 'aggregateMeterId', 'type': 'int'},
        'begin_period': {'key': 'beginPeriod', 'type': 'int'},
        'source_meter_ids': {'key': 'sourceMeterIds', 'type': '[int]'},
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'aggregate_meter_info': {'key': 'aggregateMeterInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(UpsertAggregateMeterRequest, self).__init__(**kwargs)
        self.aggregate_meter_id = kwargs.get('aggregate_meter_id', None)
        self.begin_period = kwargs.get('begin_period', None)
        self.source_meter_ids = kwargs.get('source_meter_ids', None)
        self.commodity_id = kwargs.get('commodity_id', None)
        self.aggregate_meter_info = kwargs.get('aggregate_meter_info', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DistributeAccountChargesBase(Model):
    """DistributeAccountChargesBase.

    :param split_basis:
    :type split_basis: int
    """

    _attribute_map = {
        'split_basis': {'key': 'splitBasis', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(DistributeAccountChargesBase, self).__init__(**kwargs)
        self.split_basis = kwargs.get('split_basis', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SearchAccountMeterBillEntry(Model):
    """SearchAccountMeterBillEntry.

    :param match_type: The MatchType
     values -
     Account - we found a match on account code, account info or previous
     account code
     Meter - we found a match on meter code, meter info or serial number
     AccountAddress - we found a match on account's address - line1, line2,
     city or state
     MeterAddress - we found a match on meter's address - line1, line2, city or
     state
    :type match_type: str
    :param account_id: The Account identifier
    :type account_id: int
    :param account_code: The Account code
    :type account_code: str
    :param account_info: The Account info
    :type account_info: str
    :param previous_account_code: The Previous Account code
    :type previous_account_code: str
    :param active: Indicates whether the Account is active or inactive
    :type active: bool
    :param account_type:
    :type account_type: ~energycap.sdk.models.AccountTypeChild
    :param has_calculated_meter: Indicates whether the Account has a child
     calculated meter
    :type has_calculated_meter: bool
    :param has_split_parent_meter: Indicates whether the Account is a
     recipient of a split
    :type has_split_parent_meter: bool
    :param has_split_child_meter: Indicates whether the Account has a child
     split meter
    :type has_split_child_meter: bool
    :param vendor:
    :type vendor: ~energycap.sdk.models.VendorChild
    :param account_address:
    :type account_address: ~energycap.sdk.models.AddressChild
    :param meters: The Account's vendor
    :type meters: list[~energycap.sdk.models.MeterChildSearch]
    """

    _attribute_map = {
        'match_type': {'key': 'matchType', 'type': 'str'},
        'account_id': {'key': 'accountId', 'type': 'int'},
        'account_code': {'key': 'accountCode', 'type': 'str'},
        'account_info': {'key': 'accountInfo', 'type': 'str'},
        'previous_account_code': {'key': 'previousAccountCode', 'type': 'str'},
        'active': {'key': 'active', 'type': 'bool'},
        'account_type': {'key': 'accountType', 'type': 'AccountTypeChild'},
        'has_calculated_meter': {'key': 'hasCalculatedMeter', 'type': 'bool'},
        'has_split_parent_meter': {'key': 'hasSplitParentMeter', 'type': 'bool'},
        'has_split_child_meter': {'key': 'hasSplitChildMeter', 'type': 'bool'},
        'vendor': {'key': 'vendor', 'type': 'VendorChild'},
        'account_address': {'key': 'accountAddress', 'type': 'AddressChild'},
        'meters': {'key': 'meters', 'type': '[MeterChildSearch]'},
    }

    def __init__(self, *, match_type: str=None, account_id: int=None, account_code: str=None, account_info: str=None, previous_account_code: str=None, active: bool=None, account_type=None, has_calculated_meter: bool=None, has_split_parent_meter: bool=None, has_split_child_meter: bool=None, vendor=None, account_address=None, meters=None, **kwargs) -> None:
        super(SearchAccountMeterBillEntry, self).__init__(**kwargs)
        self.match_type = match_type
        self.account_id = account_id
        self.account_code = account_code
        self.account_info = account_info
        self.previous_account_code = previous_account_code
        self.active = active
        self.account_type = account_type
        self.has_calculated_meter = has_calculated_meter
        self.has_split_parent_meter = has_split_parent_meter
        self.has_split_child_meter = has_split_child_meter
        self.vendor = vendor
        self.account_address = account_address
        self.meters = meters



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AddressLookup(Model):
    """AddressLookup.

    :param address_type_id:
    :type address_type_id: int
    :param line1:
    :type line1: str
    :param line2:
    :type line2: str
    :param line3:
    :type line3: str
    :param city:
    :type city: str
    :param state:
    :type state: str
    :param country:
    :type country: str
    :param postal_code:
    :type postal_code: str
    :param latitude:
    :type latitude: float
    :param longitude:
    :type longitude: float
    :param unique_location_identifier:
    :type unique_location_identifier: str
    :param location_properties:
    :type location_properties: dict[str, object]
    """

    _attribute_map = {
        'address_type_id': {'key': 'addressTypeId', 'type': 'int'},
        'line1': {'key': 'line1', 'type': 'str'},
        'line2': {'key': 'line2', 'type': 'str'},
        'line3': {'key': 'line3', 'type': 'str'},
        'city': {'key': 'city', 'type': 'str'},
        'state': {'key': 'state', 'type': 'str'},
        'country': {'key': 'country', 'type': 'str'},
        'postal_code': {'key': 'postalCode', 'type': 'str'},
        'latitude': {'key': 'latitude', 'type': 'float'},
        'longitude': {'key': 'longitude', 'type': 'float'},
        'unique_location_identifier': {'key': 'uniqueLocationIdentifier', 'type': 'str'},
        'location_properties': {'key': 'locationProperties', 'type': '{object}'},
    }

    def __init__(self, *, address_type_id: int=None, line1: str=None, line2: str=None, line3: str=None, city: str=None, state: str=None, country: str=None, postal_code: str=None, latitude: float=None, longitude: float=None, unique_location_identifier: str=None, location_properties=None, **kwargs) -> None:
        super(AddressLookup, self).__init__(**kwargs)
        self.address_type_id = address_type_id
        self.line1 = line1
        self.line2 = line2
        self.line3 = line3
        self.city = city
        self.state = state
        self.country = country
        self.postal_code = postal_code
        self.latitude = latitude
        self.longitude = longitude
        self.unique_location_identifier = unique_location_identifier
        self.location_properties = location_properties



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class VersionResponse(Model):
    """VersionResponse.

    :param version_id:
    :type version_id: int
    :param begin_date:
    :type begin_date: datetime
    :param end_date:
    :type end_date: datetime
    """

    _attribute_map = {
        'version_id': {'key': 'versionId', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(VersionResponse, self).__init__(**kwargs)
        self.version_id = kwargs.get('version_id', None)
        self.begin_date = kwargs.get('begin_date', None)
        self.end_date = kwargs.get('end_date', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UpdateBatchStatusRequest(Model):
    """UpdateBatchStatusRequest.

    All required parameters must be populated in order to send to Azure.

    :param batch_status: Required. The status to set on the batch <span
     class='property-internal'>Required</span> <span
     class='property-internal'>One of Open, Pending, Closed </span>
    :type batch_status: str
    :param note: The batch note, referred to as a comment in the application
     when setting state to pending.
     If opening another user's batch, the note will only be applied to the
     requesting user's open batch that is being set to pending (if any).
     If null, the note will not be updated. Set to an empty string to remove
     the current note. <span class='property-internal'>Must be between 0 and
     255 characters</span> <span class='property-internal'>Required
     (defined)</span>
    :type note: str
    """

    _validation = {
        'batch_status': {'required': True},
        'note': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'batch_status': {'key': 'batchStatus', 'type': 'str'},
        'note': {'key': 'note', 'type': 'str'},
    }

    def __init__(self, *, batch_status: str, note: str=None, **kwargs) -> None:
        super(UpdateBatchStatusRequest, self).__init__(**kwargs)
        self.batch_status = batch_status
        self.note = note



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CommodityDigestActualYearlyResponse(Model):
    """CommodityDigestActualYearlyResponse.

    :param global_use_unit:
    :type global_use_unit: ~energycap.sdk.models.UnitChild
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param updated: The date and time the data was updated
    :type updated: datetime
    :param results: An array of yearly data
    :type results:
     list[~energycap.sdk.models.CommodityDigestActualYearlyResponseResults]
    :param commodities: An array of yearly data per commodity
    :type commodities:
     list[~energycap.sdk.models.CommodityDigestActualYearlyResponseCommodityData]
    """

    _attribute_map = {
        'global_use_unit': {'key': 'globalUseUnit', 'type': 'UnitChild'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
        'results': {'key': 'results', 'type': '[CommodityDigestActualYearlyResponseResults]'},
        'commodities': {'key': 'commodities', 'type': '[CommodityDigestActualYearlyResponseCommodityData]'},
    }

    def __init__(self, **kwargs):
        super(CommodityDigestActualYearlyResponse, self).__init__(**kwargs)
        self.global_use_unit = kwargs.get('global_use_unit', None)
        self.cost_unit = kwargs.get('cost_unit', None)
        self.updated = kwargs.get('updated', None)
        self.results = kwargs.get('results', None)
        self.commodities = kwargs.get('commodities', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FormTemplateChild(Model):
    """FormTemplateChild.

    :param form_template_id:
    :type form_template_id: int
    :param display_order:
    :type display_order: int
    :param template:
    :type template: ~energycap.sdk.models.TemplateChild
    :param begin_date:
    :type begin_date: datetime
    :param end_date:
    :type end_date: datetime
    """

    _attribute_map = {
        'form_template_id': {'key': 'formTemplateId', 'type': 'int'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
        'template': {'key': 'template', 'type': 'TemplateChild'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(FormTemplateChild, self).__init__(**kwargs)
        self.form_template_id = kwargs.get('form_template_id', None)
        self.display_order = kwargs.get('display_order', None)
        self.template = kwargs.get('template', None)
        self.begin_date = kwargs.get('begin_date', None)
        self.end_date = kwargs.get('end_date', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MostRecentAggregate(Model):
    """MostRecentAggregate.

    :param aggregate_meter_id: The identifier of the aggregate meter
    :type aggregate_meter_id: int
    :param effective_date: The effective date of the aggregation
    :type effective_date: datetime
    """

    _attribute_map = {
        'aggregate_meter_id': {'key': 'aggregateMeterId', 'type': 'int'},
        'effective_date': {'key': 'effectiveDate', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(MostRecentAggregate, self).__init__(**kwargs)
        self.aggregate_meter_id = kwargs.get('aggregate_meter_id', None)
        self.effective_date = kwargs.get('effective_date', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MoveCreateMeter(Model):
    """MoveCreateMeter.

    :param meter_code: The meter code
    :type meter_code: str
    :param meter_display: The meter display name
    :type meter_display: str
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param serial_number: The meter serial number
    :type serial_number: str
    """

    _attribute_map = {
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_display': {'key': 'meterDisplay', 'type': 'str'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'serial_number': {'key': 'serialNumber', 'type': 'str'},
    }

    def __init__(self, *, meter_code: str=None, meter_display: str=None, commodity=None, serial_number: str=None, **kwargs) -> None:
        super(MoveCreateMeter, self).__init__(**kwargs)
        self.meter_code = meter_code
        self.meter_display = meter_display
        self.commodity = commodity
        self.serial_number = serial_number



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Vendors(Model):
    """Vendors.

    :param create:
    :type create: bool
    :param edit:
    :type edit: bool
    :param delete:
    :type delete: bool
    :param permission_id:
    :type permission_id: int
    :param permission_code:
    :type permission_code: str
    :param permission_name:
    :type permission_name: str
    :param description:
    :type description: str
    :param permission_category_name:
    :type permission_category_name: str
    :param is_licensed:
    :type is_licensed: bool
    """

    _attribute_map = {
        'create': {'key': 'create', 'type': 'bool'},
        'edit': {'key': 'edit', 'type': 'bool'},
        'delete': {'key': 'delete', 'type': 'bool'},
        'permission_id': {'key': 'permissionId', 'type': 'int'},
        'permission_code': {'key': 'permissionCode', 'type': 'str'},
        'permission_name': {'key': 'permissionName', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'permission_category_name': {'key': 'permissionCategoryName', 'type': 'str'},
        'is_licensed': {'key': 'isLicensed', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(Vendors, self).__init__(**kwargs)
        self.create = kwargs.get('create', None)
        self.edit = kwargs.get('edit', None)
        self.delete = kwargs.get('delete', None)
        self.permission_id = kwargs.get('permission_id', None)
        self.permission_code = kwargs.get('permission_code', None)
        self.permission_name = kwargs.get('permission_name', None)
        self.description = kwargs.get('description', None)
        self.permission_category_name = kwargs.get('permission_category_name', None)
        self.is_licensed = kwargs.get('is_licensed', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterCAPResponse(Model):
    """MeterCAPResponse.

    :param base_start: The meter's baseline start date
    :type base_start: datetime
    :param saving_start: The meter's savings start date
    :type saving_start: datetime
    :param include_in_cap: Indicates if the meter is included or not included
     in cost avoidance calculations
    :type include_in_cap: bool
    """

    _attribute_map = {
        'base_start': {'key': 'baseStart', 'type': 'iso-8601'},
        'saving_start': {'key': 'savingStart', 'type': 'iso-8601'},
        'include_in_cap': {'key': 'includeInCAP', 'type': 'bool'},
    }

    def __init__(self, *, base_start=None, saving_start=None, include_in_cap: bool=None, **kwargs) -> None:
        super(MeterCAPResponse, self).__init__(**kwargs)
        self.base_start = base_start
        self.saving_start = saving_start
        self.include_in_cap = include_in_cap



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SearchAccountChild(Model):
    """SearchAccountChild.

    :param result:
    :type result: ~energycap.sdk.models.SearchAccountChildSearchAccountChild
    """

    _attribute_map = {
        'result': {'key': 'result', 'type': 'SearchAccountChildSearchAccountChild'},
    }

    def __init__(self, **kwargs):
        super(SearchAccountChild, self).__init__(**kwargs)
        self.result = kwargs.get('result', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListActionReverse(Model):
    """ListActionReverse.

    :param batch_settings:
    :type batch_settings: ~energycap.sdk.models.BatchCreate
    """

    _attribute_map = {
        'batch_settings': {'key': 'batchSettings', 'type': 'BatchCreate'},
    }

    def __init__(self, *, batch_settings=None, **kwargs) -> None:
        super(ListActionReverse, self).__init__(**kwargs)
        self.batch_settings = batch_settings



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SubtractRequest(Model):
    """SubtractRequest.

    :param subtract_meter_ids: Meters in this list will have their use or cost
     subtracted during bill calculation <span
     class='property-internal'>Required (defined)</span>
    :type subtract_meter_ids: list[int]
    :param subtract_meter_group_ids: Distinct meters from these meter groups
     will have their use or cost subtracted together during the bill
     calculation
     System auto groups cannot be used <span class='property-internal'>Required
     (defined)</span>
    :type subtract_meter_group_ids: list[int]
    """

    _attribute_map = {
        'subtract_meter_ids': {'key': 'subtractMeterIds', 'type': '[int]'},
        'subtract_meter_group_ids': {'key': 'subtractMeterGroupIds', 'type': '[int]'},
    }

    def __init__(self, *, subtract_meter_ids=None, subtract_meter_group_ids=None, **kwargs) -> None:
        super(SubtractRequest, self).__init__(**kwargs)
        self.subtract_meter_ids = subtract_meter_ids
        self.subtract_meter_group_ids = subtract_meter_group_ids



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UtilityPlatform(Model):
    """UtilityPlatform.

    :param data_release_file_url: Date Release file Url used to record Data
     access release
    :type data_release_file_url: str
    """

    _attribute_map = {
        'data_release_file_url': {'key': 'dataReleaseFileUrl', 'type': 'str'},
    }

    def __init__(self, *, data_release_file_url: str=None, **kwargs) -> None:
        super(UtilityPlatform, self).__init__(**kwargs)
        self.data_release_file_url = data_release_file_url



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UDFSelectValueEntityResponse(Model):
    """UDFSelectValueEntityResponse.

    :param udf_select_value_id:  <span class='property-internal'>Required
     (defined)</span>
    :type udf_select_value_id: int
    :param value:  <span class='property-internal'>Required (defined)</span>
    :type value: str
    :param display_order:  <span class='property-internal'>Required
     (defined)</span>
    :type display_order: int
    """

    _attribute_map = {
        'udf_select_value_id': {'key': 'udfSelectValueId', 'type': 'int'},
        'value': {'key': 'value', 'type': 'str'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
    }

    def __init__(self, *, udf_select_value_id: int=None, value: str=None, display_order: int=None, **kwargs) -> None:
        super(UDFSelectValueEntityResponse, self).__init__(**kwargs)
        self.udf_select_value_id = udf_select_value_id
        self.value = value
        self.display_order = display_order



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChannelVersionResponse(Model):
    """ChannelVersionResponse.

    :param channel_version_id: The channel version identifier
    :type channel_version_id: int
    :param multiplier: The channel multiplier
    :type multiplier: float
    :param unit:
    :type unit: ~energycap.sdk.models.UnitChild
    :param observation_rule:
    :type observation_rule: ~energycap.sdk.models.ObservationRule
    :param maximum_reading: The channel's max reading
    :type maximum_reading: float
    :param begin_date: Date this channel version started to be used
    :type begin_date: datetime
    :param end_date: Date this channel version stopped being used
    :type end_date: datetime
    :param udfs: List of user defined/custom fields and values for this
     version
    :type udfs: list[~energycap.sdk.models.UDFFieldChild]
    """

    _attribute_map = {
        'channel_version_id': {'key': 'channelVersionId', 'type': 'int'},
        'multiplier': {'key': 'multiplier', 'type': 'float'},
        'unit': {'key': 'unit', 'type': 'UnitChild'},
        'observation_rule': {'key': 'observationRule', 'type': 'ObservationRule'},
        'maximum_reading': {'key': 'maximumReading', 'type': 'float'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'udfs': {'key': 'udfs', 'type': '[UDFFieldChild]'},
    }

    def __init__(self, *, channel_version_id: int=None, multiplier: float=None, unit=None, observation_rule=None, maximum_reading: float=None, begin_date=None, end_date=None, udfs=None, **kwargs) -> None:
        super(ChannelVersionResponse, self).__init__(**kwargs)
        self.channel_version_id = channel_version_id
        self.multiplier = multiplier
        self.unit = unit
        self.observation_rule = observation_rule
        self.maximum_reading = maximum_reading
        self.begin_date = begin_date
        self.end_date = end_date
        self.udfs = udfs



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BatchWorkflowSettings(Model):
    """BatchWorkflowSettings.

    :param batch_mode_enabled:
    :type batch_mode_enabled: bool
    :param due_date:
    :type due_date: ~energycap.sdk.models.BillHeaderWorkflowChild
    :param statement_date:
    :type statement_date: ~energycap.sdk.models.BillHeaderWorkflowChild
    :param invoice_number:
    :type invoice_number: ~energycap.sdk.models.BillHeaderWorkflowChild
    :param control_code:
    :type control_code: ~energycap.sdk.models.BillHeaderWorkflowChild
    :param next_reading:
    :type next_reading: ~energycap.sdk.models.BillHeaderWorkflowChild
    :param account_period_name:
    :type account_period_name: ~energycap.sdk.models.BillHeaderWorkflowChild
    :param account_period_year:
    :type account_period_year: ~energycap.sdk.models.BillHeaderWorkflowChild
    """

    _attribute_map = {
        'batch_mode_enabled': {'key': 'batchModeEnabled', 'type': 'bool'},
        'due_date': {'key': 'dueDate', 'type': 'BillHeaderWorkflowChild'},
        'statement_date': {'key': 'statementDate', 'type': 'BillHeaderWorkflowChild'},
        'invoice_number': {'key': 'invoiceNumber', 'type': 'BillHeaderWorkflowChild'},
        'control_code': {'key': 'controlCode', 'type': 'BillHeaderWorkflowChild'},
        'next_reading': {'key': 'nextReading', 'type': 'BillHeaderWorkflowChild'},
        'account_period_name': {'key': 'accountPeriodName', 'type': 'BillHeaderWorkflowChild'},
        'account_period_year': {'key': 'accountPeriodYear', 'type': 'BillHeaderWorkflowChild'},
    }

    def __init__(self, **kwargs):
        super(BatchWorkflowSettings, self).__init__(**kwargs)
        self.batch_mode_enabled = kwargs.get('batch_mode_enabled', None)
        self.due_date = kwargs.get('due_date', None)
        self.statement_date = kwargs.get('statement_date', None)
        self.invoice_number = kwargs.get('invoice_number', None)
        self.control_code = kwargs.get('control_code', None)
        self.next_reading = kwargs.get('next_reading', None)
        self.account_period_name = kwargs.get('account_period_name', None)
        self.account_period_year = kwargs.get('account_period_year', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarPlaceHierarchyResponse(Model):
    """EnergyStarPlaceHierarchyResponse.

    :param place:
    :type place: ~energycap.sdk.models.PlaceChild
    :param place_size:
    :type place_size: ~energycap.sdk.models.PlaceSizeChild
    :param place_submission_type:
    :type place_submission_type: ~energycap.sdk.models.SubmissionTypeResponse
    :param latest_submission_status: The status of the latest submission for
     this place
    :type latest_submission_status: str
    :param latest_submission_date: The date that the latest submission for
     this place occurred
    :type latest_submission_date: datetime
    :param latest_metrics_retrieval_status: The status of the latest metrics
     retrieval for this place
    :type latest_metrics_retrieval_status: str
    :param metrics: ENERGY STAR score data for the place
     If there are multiple places returned in the response, will be the most
     recent score
    :type metrics: list[~energycap.sdk.models.EnergyStarPlaceMetricsResponse]
    """

    _attribute_map = {
        'place': {'key': 'place', 'type': 'PlaceChild'},
        'place_size': {'key': 'placeSize', 'type': 'PlaceSizeChild'},
        'place_submission_type': {'key': 'placeSubmissionType', 'type': 'SubmissionTypeResponse'},
        'latest_submission_status': {'key': 'latestSubmissionStatus', 'type': 'str'},
        'latest_submission_date': {'key': 'latestSubmissionDate', 'type': 'iso-8601'},
        'latest_metrics_retrieval_status': {'key': 'latestMetricsRetrievalStatus', 'type': 'str'},
        'metrics': {'key': 'metrics', 'type': '[EnergyStarPlaceMetricsResponse]'},
    }

    def __init__(self, *, place=None, place_size=None, place_submission_type=None, latest_submission_status: str=None, latest_submission_date=None, latest_metrics_retrieval_status: str=None, metrics=None, **kwargs) -> None:
        super(EnergyStarPlaceHierarchyResponse, self).__init__(**kwargs)
        self.place = place
        self.place_size = place_size
        self.place_submission_type = place_submission_type
        self.latest_submission_status = latest_submission_status
        self.latest_submission_date = latest_submission_date
        self.latest_metrics_retrieval_status = latest_metrics_retrieval_status
        self.metrics = metrics



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ExportFormatChild(Model):
    """ExportFormatChild.

    :param export_format_info:
    :type export_format_info: str
    :param preferred:
    :type preferred: bool
    """

    _attribute_map = {
        'export_format_info': {'key': 'exportFormatInfo', 'type': 'str'},
        'preferred': {'key': 'preferred', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(ExportFormatChild, self).__init__(**kwargs)
        self.export_format_info = kwargs.get('export_format_info', None)
        self.preferred = kwargs.get('preferred', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NotificationType(Model):
    """NotificationType.

    :param notification_type_id: The id of the notification type
    :type notification_type_id: int
    :param notification_type_info: The notification type name
    :type notification_type_info: str
    :param notification_type_description: A description of the notification
     type
    :type notification_type_description: str
    :param notification_category:
    :type notification_category: ~energycap.sdk.models.NotificationCategory
    """

    _attribute_map = {
        'notification_type_id': {'key': 'notificationTypeId', 'type': 'int'},
        'notification_type_info': {'key': 'notificationTypeInfo', 'type': 'str'},
        'notification_type_description': {'key': 'notificationTypeDescription', 'type': 'str'},
        'notification_category': {'key': 'notificationCategory', 'type': 'NotificationCategory'},
    }

    def __init__(self, *, notification_type_id: int=None, notification_type_info: str=None, notification_type_description: str=None, notification_category=None, **kwargs) -> None:
        super(NotificationType, self).__init__(**kwargs)
        self.notification_type_id = notification_type_id
        self.notification_type_info = notification_type_info
        self.notification_type_description = notification_type_description
        self.notification_category = notification_category



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WebhookLogDetailsResponse(Model):
    """WebhookLogDetailsResponse.

    :param url: The URL that the webhook is configured for <span
     class='property-internal'>Required (defined)</span>
    :type url: str
    :param request: The request that was sent from the webhook (headers and
     body) <span class='property-internal'>Required (defined)</span>
    :type request: str
    :param response: The response that was received from the configured url
     (headers and body) <span class='property-internal'>Required
     (defined)</span>
    :type response: str
    :param result: The HTTP status code that was received from the configured
     url
     0 indicates no response was received from the configured url <span
     class='property-internal'>Required (defined)</span>
    :type result: str
    :param user:
    :type user: ~energycap.sdk.models.UserChild
    """

    _attribute_map = {
        'url': {'key': 'url', 'type': 'str'},
        'request': {'key': 'request', 'type': 'str'},
        'response': {'key': 'response', 'type': 'str'},
        'result': {'key': 'result', 'type': 'str'},
        'user': {'key': 'user', 'type': 'UserChild'},
    }

    def __init__(self, *, url: str=None, request: str=None, response: str=None, result: str=None, user=None, **kwargs) -> None:
        super(WebhookLogDetailsResponse, self).__init__(**kwargs)
        self.url = url
        self.request = request
        self.response = response
        self.result = result
        self.user = user



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestSavingsYearlyResponseResults(Model):
    """PlaceDigestSavingsYearlyResponseResults.

    :param year: Year
    :type year: str
    :param batcc_total_cost: BATCC (Baseline Adjusted to Current Conditions)
     Total Cost
    :type batcc_total_cost: float
    :param total_cost: Total Cost
    :type total_cost: float
    :param savings_total_cost: Savings Total Cost = BATCCTotalCost - TotalCost
    :type savings_total_cost: float
    :param batcc_global_use: BATCC (Baseline Adjusted to Current Conditions)
     Global Use
    :type batcc_global_use: float
    :param global_use: GlobalUse
    :type global_use: float
    :param savings_global_use: Savings Global Use = BATCCGlobalUse - GlobalUse
    :type savings_global_use: float
    """

    _attribute_map = {
        'year': {'key': 'year', 'type': 'str'},
        'batcc_total_cost': {'key': 'batccTotalCost', 'type': 'float'},
        'total_cost': {'key': 'totalCost', 'type': 'float'},
        'savings_total_cost': {'key': 'savingsTotalCost', 'type': 'float'},
        'batcc_global_use': {'key': 'batccGlobalUse', 'type': 'float'},
        'global_use': {'key': 'globalUse', 'type': 'float'},
        'savings_global_use': {'key': 'savingsGlobalUse', 'type': 'float'},
    }

    def __init__(self, *, year: str=None, batcc_total_cost: float=None, total_cost: float=None, savings_total_cost: float=None, batcc_global_use: float=None, global_use: float=None, savings_global_use: float=None, **kwargs) -> None:
        super(PlaceDigestSavingsYearlyResponseResults, self).__init__(**kwargs)
        self.year = year
        self.batcc_total_cost = batcc_total_cost
        self.total_cost = total_cost
        self.savings_total_cost = savings_total_cost
        self.batcc_global_use = batcc_global_use
        self.global_use = global_use
        self.savings_global_use = savings_global_use



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PmCommodityChild(Model):
    """PmCommodityChild.

    :param pm_commodity_code: Commodity code from Portfolio Manager
    :type pm_commodity_code: str
    :param is_default: When true, auto-created Portfolio Manager meters will
     be of this commodity
    :type is_default: bool
    """

    _attribute_map = {
        'pm_commodity_code': {'key': 'pmCommodityCode', 'type': 'str'},
        'is_default': {'key': 'isDefault', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(PmCommodityChild, self).__init__(**kwargs)
        self.pm_commodity_code = kwargs.get('pm_commodity_code', None)
        self.is_default = kwargs.get('is_default', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UDFResponse(Model):
    """UDFResponse.

    :param udf_id: The identifier of the custom field. <span
     class='property-internal'>Required (defined)</span>
    :type udf_id: int
    :param name: The name of the custom field. <span
     class='property-internal'>Required (defined)</span>
    :type name: str
    :param udf_type: The type of the udf. Values include: Account, Meter,
     Vendor, Place, ChannelVersion, Rate, and Bill. <span
     class='property-internal'>Required (defined)</span>
    :type udf_type: str
    :param data_type:
    :type data_type: ~energycap.sdk.models.DataTypeResponse
    :param display_order: The display order of the custom field. <span
     class='property-internal'>Required (defined)</span>
    :type display_order: int
    :param udf_select_values: Select values of the custom field, if it is a
     select list (DataType = 12). <span class='property-internal'>Required
     (defined)</span>
    :type udf_select_values:
     list[~energycap.sdk.models.UDFSelectValueResponse]
    :param count: The number of times this custom field has been used. <span
     class='property-internal'>Required (defined)</span>
    :type count: int
    :param locked: If true, then this udf is a system custom field <span
     class='property-internal'>Required (defined)</span>
    :type locked: bool
    """

    _attribute_map = {
        'udf_id': {'key': 'udfId', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'udf_type': {'key': 'udfType', 'type': 'str'},
        'data_type': {'key': 'dataType', 'type': 'DataTypeResponse'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
        'udf_select_values': {'key': 'udfSelectValues', 'type': '[UDFSelectValueResponse]'},
        'count': {'key': 'count', 'type': 'int'},
        'locked': {'key': 'locked', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(UDFResponse, self).__init__(**kwargs)
        self.udf_id = kwargs.get('udf_id', None)
        self.name = kwargs.get('name', None)
        self.udf_type = kwargs.get('udf_type', None)
        self.data_type = kwargs.get('data_type', None)
        self.display_order = kwargs.get('display_order', None)
        self.udf_select_values = kwargs.get('udf_select_values', None)
        self.count = kwargs.get('count', None)
        self.locked = kwargs.get('locked', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebackWorkflowCreate(Model):
    """ChargebackWorkflowCreate.

    All required parameters must be populated in order to send to Azure.

    :param chargeback_workflow_info: Required. Name given to the chargeback
     workflow <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type chargeback_workflow_info: str
    :param chargeback_workflow_steps: List of chargeback workflow steps with
     details
     Order of the steps in the list determines the steps in the workflow. <span
     class='property-internal'>Cannot be Empty</span>
    :type chargeback_workflow_steps:
     list[~energycap.sdk.models.ChargebackWorkflowStepCreate]
    """

    _validation = {
        'chargeback_workflow_info': {'required': True, 'max_length': 64, 'min_length': 0},
    }

    _attribute_map = {
        'chargeback_workflow_info': {'key': 'chargebackWorkflowInfo', 'type': 'str'},
        'chargeback_workflow_steps': {'key': 'chargebackWorkflowSteps', 'type': '[ChargebackWorkflowStepCreate]'},
    }

    def __init__(self, *, chargeback_workflow_info: str, chargeback_workflow_steps=None, **kwargs) -> None:
        super(ChargebackWorkflowCreate, self).__init__(**kwargs)
        self.chargeback_workflow_info = chargeback_workflow_info
        self.chargeback_workflow_steps = chargeback_workflow_steps



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportsModule(Model):
    """ReportsModule.

    :param view:
    :type view: bool
    :param permission_id:
    :type permission_id: int
    :param permission_code:
    :type permission_code: str
    :param permission_name:
    :type permission_name: str
    :param description:
    :type description: str
    :param permission_category_name:
    :type permission_category_name: str
    :param is_licensed:
    :type is_licensed: bool
    """

    _attribute_map = {
        'view': {'key': 'view', 'type': 'bool'},
        'permission_id': {'key': 'permissionId', 'type': 'int'},
        'permission_code': {'key': 'permissionCode', 'type': 'str'},
        'permission_name': {'key': 'permissionName', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'permission_category_name': {'key': 'permissionCategoryName', 'type': 'str'},
        'is_licensed': {'key': 'isLicensed', 'type': 'bool'},
    }

    def __init__(self, *, view: bool=None, permission_id: int=None, permission_code: str=None, permission_name: str=None, description: str=None, permission_category_name: str=None, is_licensed: bool=None, **kwargs) -> None:
        super(ReportsModule, self).__init__(**kwargs)
        self.view = view
        self.permission_id = permission_id
        self.permission_code = permission_code
        self.permission_name = permission_name
        self.description = description
        self.permission_category_name = permission_category_name
        self.is_licensed = is_licensed



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class StatementDateTooLongAfterBillEndSettingRequest(Model):
    """StatementDateTooLongAfterBillEndSettingRequest.

    :param days: Threshold for how long the statement date can be after the
     end date
     If SettingStatus is set to Skip and no value is provided, EnergyCAP
     default will be set <span class='property-internal'>Must be between 0 and
     2147483647</span> <span class='property-internal'>Required when
     SettingStatus is set to Check, or Hold</span>
    :type days: int
    :param setting_status: The status of the audit setting <span
     class='property-internal'>One of Check, Hold, Skip </span> <span
     class='property-internal'>Required (defined)</span>
    :type setting_status: str
    :param minimum_cost: Minimum Bill/Meter Cost.
     This audit will run only when the cost meets the specified minimum cost
     <span class='property-internal'>Required (defined)</span>
    :type minimum_cost: int
    :param assignees: List of Assignees.
     Ids of the users the flag should get assigned to when the audit fails.
     <span class='property-internal'>Required (defined)</span>
    :type assignees: list[int]
    """

    _validation = {
        'days': {'maximum': 2147483647, 'minimum': 0},
    }

    _attribute_map = {
        'days': {'key': 'days', 'type': 'int'},
        'setting_status': {'key': 'settingStatus', 'type': 'str'},
        'minimum_cost': {'key': 'minimumCost', 'type': 'int'},
        'assignees': {'key': 'assignees', 'type': '[int]'},
    }

    def __init__(self, **kwargs):
        super(StatementDateTooLongAfterBillEndSettingRequest, self).__init__(**kwargs)
        self.days = kwargs.get('days', None)
        self.setting_status = kwargs.get('setting_status', None)
        self.minimum_cost = kwargs.get('minimum_cost', None)
        self.assignees = kwargs.get('assignees', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceGroupDigestAreaRankingChild(Model):
    """PlaceGroupDigestAreaRankingChild.

    :param cost: The cost for this place
    :type cost: float
    :param use: The use for this place
    :type use: float
    :param value: The benchmark value for this place
    :type value: float
    :param area: The area for this place
    :type area: int
    :param savings_opportunity: The savings opportunity for this place
    :type savings_opportunity: float
    :param incomplete_data: Does this place have incomplete data?
    :type incomplete_data: bool
    :param place_id:
    :type place_id: int
    :param place_code:
    :type place_code: str
    :param place_info:
    :type place_info: str
    :param place_display:
    :type place_display: str
    :param include_in_charts:
    :type include_in_charts: bool
    """

    _attribute_map = {
        'cost': {'key': 'cost', 'type': 'float'},
        'use': {'key': 'use', 'type': 'float'},
        'value': {'key': 'value', 'type': 'float'},
        'area': {'key': 'area', 'type': 'int'},
        'savings_opportunity': {'key': 'savingsOpportunity', 'type': 'float'},
        'incomplete_data': {'key': 'incompleteData', 'type': 'bool'},
        'place_id': {'key': 'placeId', 'type': 'int'},
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'place_display': {'key': 'placeDisplay', 'type': 'str'},
        'include_in_charts': {'key': 'includeInCharts', 'type': 'bool'},
    }

    def __init__(self, *, cost: float=None, use: float=None, value: float=None, area: int=None, savings_opportunity: float=None, incomplete_data: bool=None, place_id: int=None, place_code: str=None, place_info: str=None, place_display: str=None, include_in_charts: bool=None, **kwargs) -> None:
        super(PlaceGroupDigestAreaRankingChild, self).__init__(**kwargs)
        self.cost = cost
        self.use = use
        self.value = value
        self.area = area
        self.savings_opportunity = savings_opportunity
        self.incomplete_data = incomplete_data
        self.place_id = place_id
        self.place_code = place_code
        self.place_info = place_info
        self.place_display = place_display
        self.include_in_charts = include_in_charts



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillImportProfileColumnMapping(Model):
    """BillImportProfileColumnMapping.

    All required parameters must be populated in order to send to Azure.

    :param date_format: Required.  <span
     class='property-internal'>Required</span> <span
     class='property-internal'>One of mm/dd/yyyy, Month dd yyyy, dd/mm/yyyy, dd
     Month yyyy, yyyymmdd </span>
    :type date_format: str
    :param account_code_column_index: Required.  <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 1 and 2147483647</span>
    :type account_code_column_index: int
    :param start_date_column_index: Required.  <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 1 and 2147483647</span>
    :type start_date_column_index: int
    :param end_date_column_index: Required.  <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 1 and 2147483647</span>
    :type end_date_column_index: int
    :param vendor_code_column_index:  <span class='property-internal'>Must be
     between 1 and 2147483647</span>
    :type vendor_code_column_index: int
    :param pay_amount_column_index:  <span class='property-internal'>Must be
     between 1 and 2147483647</span>
    :type pay_amount_column_index: int
    :param billing_period_column_index:  <span class='property-internal'>Must
     be between 1 and 2147483647</span>
    :type billing_period_column_index: int
    :param account_period_column_index:  <span class='property-internal'>Must
     be between 1 and 2147483647</span>
    :type account_period_column_index: int
    :param statement_date_column_index:  <span class='property-internal'>Must
     be between 1 and 2147483647</span>
    :type statement_date_column_index: int
    :param due_date_column_index:  <span class='property-internal'>Must be
     between 1 and 2147483647</span>
    :type due_date_column_index: int
    :param control_code_column_index:  <span class='property-internal'>Must be
     between 1 and 2147483647</span>
    :type control_code_column_index: int
    :param invoice_number_column_index:  <span class='property-internal'>Must
     be between 1 and 2147483647</span>
    :type invoice_number_column_index: int
    :param meter_code_column_index:  <span class='property-internal'>Must be
     between 1 and 2147483647</span>
    :type meter_code_column_index: int
    :param commodity_column_index:  <span class='property-internal'>Must be
     between 1 and 2147483647</span>
    :type commodity_column_index: int
    :param service_charge_column_index:  <span class='property-internal'>Must
     be between 1 and 2147483647</span>
    :type service_charge_column_index: int
    :param ace_flag_column_index:  <span class='property-internal'>Must be
     between 1 and 2147483647</span>
    :type ace_flag_column_index: int
    :param vpr_flag_column_index:  <span class='property-internal'>Must be
     between 1 and 2147483647</span>
    :type vpr_flag_column_index: int
    :param rate_column_index:  <span class='property-internal'>Must be between
     1 and 2147483647</span>
    :type rate_column_index: int
    :param serial_number_column_index:  <span class='property-internal'>Must
     be between 1 and 2147483647</span>
    :type serial_number_column_index: int
    :param bill_note_column_index:  <span class='property-internal'>Must be
     between 1 and 2147483647</span>
    :type bill_note_column_index: int
    :param observations:  <span class='property-internal'>Cannot be
     Empty</span>
    :type observations:
     list[~energycap.sdk.models.BillImportProfileObservation]
    """

    _validation = {
        'date_format': {'required': True},
        'account_code_column_index': {'required': True, 'maximum': 2147483647, 'minimum': 1},
        'start_date_column_index': {'required': True, 'maximum': 2147483647, 'minimum': 1},
        'end_date_column_index': {'required': True, 'maximum': 2147483647, 'minimum': 1},
        'vendor_code_column_index': {'maximum': 2147483647, 'minimum': 1},
        'pay_amount_column_index': {'maximum': 2147483647, 'minimum': 1},
        'billing_period_column_index': {'maximum': 2147483647, 'minimum': 1},
        'account_period_column_index': {'maximum': 2147483647, 'minimum': 1},
        'statement_date_column_index': {'maximum': 2147483647, 'minimum': 1},
        'due_date_column_index': {'maximum': 2147483647, 'minimum': 1},
        'control_code_column_index': {'maximum': 2147483647, 'minimum': 1},
        'invoice_number_column_index': {'maximum': 2147483647, 'minimum': 1},
        'meter_code_column_index': {'maximum': 2147483647, 'minimum': 1},
        'commodity_column_index': {'maximum': 2147483647, 'minimum': 1},
        'service_charge_column_index': {'maximum': 2147483647, 'minimum': 1},
        'ace_flag_column_index': {'maximum': 2147483647, 'minimum': 1},
        'vpr_flag_column_index': {'maximum': 2147483647, 'minimum': 1},
        'rate_column_index': {'maximum': 2147483647, 'minimum': 1},
        'serial_number_column_index': {'maximum': 2147483647, 'minimum': 1},
        'bill_note_column_index': {'maximum': 2147483647, 'minimum': 1},
    }

    _attribute_map = {
        'date_format': {'key': 'dateFormat', 'type': 'str'},
        'account_code_column_index': {'key': 'accountCodeColumnIndex', 'type': 'int'},
        'start_date_column_index': {'key': 'startDateColumnIndex', 'type': 'int'},
        'end_date_column_index': {'key': 'endDateColumnIndex', 'type': 'int'},
        'vendor_code_column_index': {'key': 'vendorCodeColumnIndex', 'type': 'int'},
        'pay_amount_column_index': {'key': 'payAmountColumnIndex', 'type': 'int'},
        'billing_period_column_index': {'key': 'billingPeriodColumnIndex', 'type': 'int'},
        'account_period_column_index': {'key': 'accountPeriodColumnIndex', 'type': 'int'},
        'statement_date_column_index': {'key': 'statementDateColumnIndex', 'type': 'int'},
        'due_date_column_index': {'key': 'dueDateColumnIndex', 'type': 'int'},
        'control_code_column_index': {'key': 'controlCodeColumnIndex', 'type': 'int'},
        'invoice_number_column_index': {'key': 'invoiceNumberColumnIndex', 'type': 'int'},
        'meter_code_column_index': {'key': 'meterCodeColumnIndex', 'type': 'int'},
        'commodity_column_index': {'key': 'commodityColumnIndex', 'type': 'int'},
        'service_charge_column_index': {'key': 'serviceChargeColumnIndex', 'type': 'int'},
        'ace_flag_column_index': {'key': 'aceFlagColumnIndex', 'type': 'int'},
        'vpr_flag_column_index': {'key': 'vprFlagColumnIndex', 'type': 'int'},
        'rate_column_index': {'key': 'rateColumnIndex', 'type': 'int'},
        'serial_number_column_index': {'key': 'serialNumberColumnIndex', 'type': 'int'},
        'bill_note_column_index': {'key': 'billNoteColumnIndex', 'type': 'int'},
        'observations': {'key': 'observations', 'type': '[BillImportProfileObservation]'},
    }

    def __init__(self, **kwargs):
        super(BillImportProfileColumnMapping, self).__init__(**kwargs)
        self.date_format = kwargs.get('date_format', None)
        self.account_code_column_index = kwargs.get('account_code_column_index', None)
        self.start_date_column_index = kwargs.get('start_date_column_index', None)
        self.end_date_column_index = kwargs.get('end_date_column_index', None)
        self.vendor_code_column_index = kwargs.get('vendor_code_column_index', None)
        self.pay_amount_column_index = kwargs.get('pay_amount_column_index', None)
        self.billing_period_column_index = kwargs.get('billing_period_column_index', None)
        self.account_period_column_index = kwargs.get('account_period_column_index', None)
        self.statement_date_column_index = kwargs.get('statement_date_column_index', None)
        self.due_date_column_index = kwargs.get('due_date_column_index', None)
        self.control_code_column_index = kwargs.get('control_code_column_index', None)
        self.invoice_number_column_index = kwargs.get('invoice_number_column_index', None)
        self.meter_code_column_index = kwargs.get('meter_code_column_index', None)
        self.commodity_column_index = kwargs.get('commodity_column_index', None)
        self.service_charge_column_index = kwargs.get('service_charge_column_index', None)
        self.ace_flag_column_index = kwargs.get('ace_flag_column_index', None)
        self.vpr_flag_column_index = kwargs.get('vpr_flag_column_index', None)
        self.rate_column_index = kwargs.get('rate_column_index', None)
        self.serial_number_column_index = kwargs.get('serial_number_column_index', None)
        self.bill_note_column_index = kwargs.get('bill_note_column_index', None)
        self.observations = kwargs.get('observations', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FlagTypeChild(Model):
    """FlagTypeChild.

    :param flag_type_id: The flag type identifier
    :type flag_type_id: int
    :param flag_type_info: Flag type information
    :type flag_type_info: str
    """

    _attribute_map = {
        'flag_type_id': {'key': 'flagTypeId', 'type': 'int'},
        'flag_type_info': {'key': 'flagTypeInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(FlagTypeChild, self).__init__(**kwargs)
        self.flag_type_id = kwargs.get('flag_type_id', None)
        self.flag_type_info = kwargs.get('flag_type_info', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceTypeResponse(Model):
    """PlaceTypeResponse.

    :param place_type_id: The place type identifier
    :type place_type_id: int
    :param place_type_code: The place type code
    :type place_type_code: str
    :param place_type_info: The place type info
    :type place_type_info: str
    :param structure: Indicates if the place is a structure
    :type structure: bool
    """

    _attribute_map = {
        'place_type_id': {'key': 'placeTypeId', 'type': 'int'},
        'place_type_code': {'key': 'placeTypeCode', 'type': 'str'},
        'place_type_info': {'key': 'placeTypeInfo', 'type': 'str'},
        'structure': {'key': 'structure', 'type': 'bool'},
    }

    def __init__(self, *, place_type_id: int=None, place_type_code: str=None, place_type_info: str=None, structure: bool=None, **kwargs) -> None:
        super(PlaceTypeResponse, self).__init__(**kwargs)
        self.place_type_id = place_type_id
        self.place_type_code = place_type_code
        self.place_type_info = place_type_info
        self.structure = structure



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportDistributionCreateRequest(Model):
    """ReportDistributionCreateRequest.

    All required parameters must be populated in order to send to Azure.

    :param specific_report_id: Required. The id of the report to distribute
     A new copy of the report will be created for the distribution with the
     filters specified in this request
     Any changes to the existing report will not effect the distribution copy
     Only SSRS reports are supported <span
     class='property-internal'>Required</span>
    :type specific_report_id: int
    :param report_distribution_name: Required. The name of the report
     distribution <span class='property-internal'>Must be between 0 and 255
     characters</span> <span class='property-internal'>Required</span>
    :type report_distribution_name: str
    :param report_filters: Required. List of filters to apply to the report
     <span class='property-internal'>Required</span>
    :type report_filters: list[~energycap.sdk.models.FilterEdit]
    :param reply_to_email: The email address the receiver should reply to
     <span class='property-internal'>Must be between 0 and 128
     characters</span>
    :type reply_to_email: str
    :param recipient_user_group_ids: Required. The id of each user group that
     should receive the report <span class='property-internal'>Cannot be
     Empty</span> <span class='property-internal'>Required</span>
    :type recipient_user_group_ids: list[int]
    :param email_subject: Required. The subject line of the email <span
     class='property-internal'>Must be between 0 and 255 characters</span>
     <span class='property-internal'>Required</span>
    :type email_subject: str
    :param email_message: Required. The body of the email <span
     class='property-internal'>Required</span>
    :type email_message: str
    :param report_subscription_schedule_type_id: Required. The schedule type
     of the report
     Values may be:
     Daily: 1
     Weekly: 2
     Monthly: 3
     Quarterly: 4 <span class='property-internal'>Required</span> <span
     class='property-internal'>One of 1, 2, 3, 4 </span>
    :type report_subscription_schedule_type_id: int
    :param day_indicator_value: Required. Indicates when to send the report
     for the given schedule type
     Values may be:
     Daily: 0
     Weekly: Day of Week - 0 (Sunday) to 6 (Saturday)
     Monthly: Day of Month - 1 to 28
     Quarterly: Month in Quarter - 1, 2, or 3 <span
     class='property-internal'>Must be between 0 and 28</span> <span
     class='property-internal'>Required</span>
    :type day_indicator_value: int
    :param only_send_if_data: Required. Indicates whether or not to email a
     report if it contains no data.
     When set to true, the subscribed report will not be emailed, if the report
     does not contain data.
     When set to false, if the requested report has no data, it will still be
     sent. <span class='property-internal'>Required</span>
    :type only_send_if_data: bool
    :param report_format: Required. The format in which the generated report
     should be downloaded <span class='property-internal'>Required</span> <span
     class='property-internal'>One of Excel, Excel data only, Csv, PDF, Word
     </span>
    :type report_format: str
    """

    _validation = {
        'specific_report_id': {'required': True},
        'report_distribution_name': {'required': True, 'max_length': 255, 'min_length': 0},
        'report_filters': {'required': True},
        'reply_to_email': {'max_length': 128, 'min_length': 0},
        'recipient_user_group_ids': {'required': True},
        'email_subject': {'required': True, 'max_length': 255, 'min_length': 0},
        'email_message': {'required': True},
        'report_subscription_schedule_type_id': {'required': True},
        'day_indicator_value': {'required': True, 'maximum': 28, 'minimum': 0},
        'only_send_if_data': {'required': True},
        'report_format': {'required': True},
    }

    _attribute_map = {
        'specific_report_id': {'key': 'specificReportId', 'type': 'int'},
        'report_distribution_name': {'key': 'reportDistributionName', 'type': 'str'},
        'report_filters': {'key': 'reportFilters', 'type': '[FilterEdit]'},
        'reply_to_email': {'key': 'replyToEmail', 'type': 'str'},
        'recipient_user_group_ids': {'key': 'recipientUserGroupIds', 'type': '[int]'},
        'email_subject': {'key': 'emailSubject', 'type': 'str'},
        'email_message': {'key': 'emailMessage', 'type': 'str'},
        'report_subscription_schedule_type_id': {'key': 'reportSubscriptionScheduleTypeId', 'type': 'int'},
        'day_indicator_value': {'key': 'dayIndicatorValue', 'type': 'int'},
        'only_send_if_data': {'key': 'onlySendIfData', 'type': 'bool'},
        'report_format': {'key': 'reportFormat', 'type': 'str'},
    }

    def __init__(self, *, specific_report_id: int, report_distribution_name: str, report_filters, recipient_user_group_ids, email_subject: str, email_message: str, report_subscription_schedule_type_id: int, day_indicator_value: int, only_send_if_data: bool, report_format: str, reply_to_email: str=None, **kwargs) -> None:
        super(ReportDistributionCreateRequest, self).__init__(**kwargs)
        self.specific_report_id = specific_report_id
        self.report_distribution_name = report_distribution_name
        self.report_filters = report_filters
        self.reply_to_email = reply_to_email
        self.recipient_user_group_ids = recipient_user_group_ids
        self.email_subject = email_subject
        self.email_message = email_message
        self.report_subscription_schedule_type_id = report_subscription_schedule_type_id
        self.day_indicator_value = day_indicator_value
        self.only_send_if_data = only_send_if_data
        self.report_format = report_format



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BenchmarkValue(Model):
    """BenchmarkValue.

    :param benchmark_value_id: Indicator for which benchmark factor <span
     class='property-internal'>Required (defined)</span>
    :type benchmark_value_id: int
    :param effective_date: Effective Date for the benchmark factor <span
     class='property-internal'>Required (defined)</span>
    :type effective_date: datetime
    :param end_date: End Date for the benchmark factor <span
     class='property-internal'>Required (defined)</span>
    :type end_date: datetime
    :param value: Value set for the benchmark factor <span
     class='property-internal'>Required (defined)</span>
    :type value: float
    """

    _attribute_map = {
        'benchmark_value_id': {'key': 'benchmarkValueId', 'type': 'int'},
        'effective_date': {'key': 'effectiveDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'value': {'key': 'value', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(BenchmarkValue, self).__init__(**kwargs)
        self.benchmark_value_id = kwargs.get('benchmark_value_id', None)
        self.effective_date = kwargs.get('effective_date', None)
        self.end_date = kwargs.get('end_date', None)
        self.value = kwargs.get('value', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceResponse(Model):
    """PlaceResponse.

    :param place_id: The place identifier
    :type place_id: int
    :param place_code: The place code
    :type place_code: str
    :param place_info: The place info
    :type place_info: str
    :param parent:
    :type parent: ~energycap.sdk.models.PlaceChild
    :param place_type:
    :type place_type: ~energycap.sdk.models.PlaceTypeResponse
    :param created_date: The date and time the place was created
    :type created_date: datetime
    :param created_by:
    :type created_by: ~energycap.sdk.models.UserChild
    :param modified_date: The date and time of the most recent modification to
     the place
    :type modified_date: datetime
    :param modified_by:
    :type modified_by: ~energycap.sdk.models.UserChild
    :param address:
    :type address: ~energycap.sdk.models.AddressChild
    :param build_date: The date and time the place was built
    :type build_date: datetime
    :param primary_use:
    :type primary_use: ~energycap.sdk.models.PrimaryUseChild
    :param weather_station:
    :type weather_station: ~energycap.sdk.models.WeatherStationChild
    :param size:
    :type size: ~energycap.sdk.models.PlaceSizeChild
    :param benchmark1:
    :type benchmark1: ~energycap.sdk.models.LatestBenchmarkValue
    :param benchmark2:
    :type benchmark2: ~energycap.sdk.models.LatestBenchmarkValue
    :param benchmark3:
    :type benchmark3: ~energycap.sdk.models.LatestBenchmarkValue
    :param energy_star_enabled: Tells whether energy star is enabled for the
     given place
    :type energy_star_enabled: bool
    :param energy_star_rating:
    :type energy_star_rating: ~energycap.sdk.models.EnergyStarRatingChild
    :param places: An array of child places. A child place is one directly
     beneath the current place on the buildings and meters tree
    :type places: list[~energycap.sdk.models.PlaceChild]
    :param meters: An array of child meters. A child meter is one directly
     beneath the current place on the buildings and meters tree
    :type meters: list[~energycap.sdk.models.MeterChild]
    :param contact:
    :type contact: ~energycap.sdk.models.ContactChild
    :param place_description: A description of the place
    :type place_description: str
    """

    _attribute_map = {
        'place_id': {'key': 'placeId', 'type': 'int'},
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'parent': {'key': 'parent', 'type': 'PlaceChild'},
        'place_type': {'key': 'placeType', 'type': 'PlaceTypeResponse'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'modified_date': {'key': 'modifiedDate', 'type': 'iso-8601'},
        'modified_by': {'key': 'modifiedBy', 'type': 'UserChild'},
        'address': {'key': 'address', 'type': 'AddressChild'},
        'build_date': {'key': 'buildDate', 'type': 'iso-8601'},
        'primary_use': {'key': 'primaryUse', 'type': 'PrimaryUseChild'},
        'weather_station': {'key': 'weatherStation', 'type': 'WeatherStationChild'},
        'size': {'key': 'size', 'type': 'PlaceSizeChild'},
        'benchmark1': {'key': 'benchmark1', 'type': 'LatestBenchmarkValue'},
        'benchmark2': {'key': 'benchmark2', 'type': 'LatestBenchmarkValue'},
        'benchmark3': {'key': 'benchmark3', 'type': 'LatestBenchmarkValue'},
        'energy_star_enabled': {'key': 'energyStarEnabled', 'type': 'bool'},
        'energy_star_rating': {'key': 'energyStarRating', 'type': 'EnergyStarRatingChild'},
        'places': {'key': 'places', 'type': '[PlaceChild]'},
        'meters': {'key': 'meters', 'type': '[MeterChild]'},
        'contact': {'key': 'contact', 'type': 'ContactChild'},
        'place_description': {'key': 'placeDescription', 'type': 'str'},
    }

    def __init__(self, *, place_id: int=None, place_code: str=None, place_info: str=None, parent=None, place_type=None, created_date=None, created_by=None, modified_date=None, modified_by=None, address=None, build_date=None, primary_use=None, weather_station=None, size=None, benchmark1=None, benchmark2=None, benchmark3=None, energy_star_enabled: bool=None, energy_star_rating=None, places=None, meters=None, contact=None, place_description: str=None, **kwargs) -> None:
        super(PlaceResponse, self).__init__(**kwargs)
        self.place_id = place_id
        self.place_code = place_code
        self.place_info = place_info
        self.parent = parent
        self.place_type = place_type
        self.created_date = created_date
        self.created_by = created_by
        self.modified_date = modified_date
        self.modified_by = modified_by
        self.address = address
        self.build_date = build_date
        self.primary_use = primary_use
        self.weather_station = weather_station
        self.size = size
        self.benchmark1 = benchmark1
        self.benchmark2 = benchmark2
        self.benchmark3 = benchmark3
        self.energy_star_enabled = energy_star_enabled
        self.energy_star_rating = energy_star_rating
        self.places = places
        self.meters = meters
        self.contact = contact
        self.place_description = place_description



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillMeterBodyLineEdit(Model):
    """BillMeterBodyLineEdit.

    All required parameters must be populated in order to send to Azure.

    :param body_line_id: The bodyline's id for an existing bodyline <span
     class='property-internal'>Required (defined)</span>
    :type body_line_id: int
    :param observation_type_id: Required. The bodyline's observation type
     <span class='property-internal'>Required</span>
    :type observation_type_id: int
    :param value_unit_id: The bodyline's unit of measure <span
     class='property-internal'>Required (defined)</span>
    :type value_unit_id: int
    :param value: The line item's value <span
     class='property-internal'>Required (defined)</span>
    :type value: float
    :param cost_unit_id: The bodyline's cost unit of measure for this <span
     class='property-internal'>Required (defined)</span>
    :type cost_unit_id: int
    :param cost: The cost attributed to the line item <span
     class='property-internal'>Required (defined)</span>
    :type cost: float
    :param caption: Required. The caption <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type caption: str
    """

    _validation = {
        'observation_type_id': {'required': True},
        'caption': {'required': True, 'max_length': 32, 'min_length': 0},
    }

    _attribute_map = {
        'body_line_id': {'key': 'bodyLineId', 'type': 'int'},
        'observation_type_id': {'key': 'observationTypeId', 'type': 'int'},
        'value_unit_id': {'key': 'valueUnitId', 'type': 'int'},
        'value': {'key': 'value', 'type': 'float'},
        'cost_unit_id': {'key': 'costUnitId', 'type': 'int'},
        'cost': {'key': 'cost', 'type': 'float'},
        'caption': {'key': 'caption', 'type': 'str'},
    }

    def __init__(self, *, observation_type_id: int, caption: str, body_line_id: int=None, value_unit_id: int=None, value: float=None, cost_unit_id: int=None, cost: float=None, **kwargs) -> None:
        super(BillMeterBodyLineEdit, self).__init__(**kwargs)
        self.body_line_id = body_line_id
        self.observation_type_id = observation_type_id
        self.value_unit_id = value_unit_id
        self.value = value
        self.cost_unit_id = cost_unit_id
        self.cost = cost
        self.caption = caption



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillHeaderUpdateBillingPeriodChild(Model):
    """Billing Period.

    All required parameters must be populated in order to send to Azure.

    :param billing_period:  <span class='property-internal'>Required when
     Update is set to True</span>
    :type billing_period: int
    :param update: Required. Indicates whether or not the header value is
     being updated <span class='property-internal'>Required</span>
    :type update: bool
    """

    _validation = {
        'update': {'required': True},
    }

    _attribute_map = {
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'update': {'key': 'update', 'type': 'bool'},
    }

    def __init__(self, *, update: bool, billing_period: int=None, **kwargs) -> None:
        super(BillHeaderUpdateBillingPeriodChild, self).__init__(**kwargs)
        self.billing_period = billing_period
        self.update = update



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FilterResponse(Model):
    """FilterResponse.

    :param available_operator:  <span class='property-internal'>Required
     (defined)</span>
    :type available_operator: list[str]
    :param caption:  <span class='property-internal'>Required (defined)</span>
    :type caption: str
    :param query_parameter_name:  <span class='property-internal'>Required
     (defined)</span>
    :type query_parameter_name: str
    :param field_id:  <span class='property-internal'>Required
     (defined)</span>
    :type field_id: int
    :param data_field_id:  <span class='property-internal'>Required
     (defined)</span>
    :type data_field_id: int
    :param data_type:
    :type data_type: ~energycap.sdk.models.DataTypeResponse
    :param operator:  <span class='property-internal'>Required
     (defined)</span>
    :type operator: str
    :param value:  <span class='property-internal'>Required (defined)</span>
    :type value: str
    :param required:  <span class='property-internal'>Required
     (defined)</span>
    :type required: bool
    :param recommended:  <span class='property-internal'>Required
     (defined)</span>
    :type recommended: bool
    """

    _attribute_map = {
        'available_operator': {'key': 'availableOperator', 'type': '[str]'},
        'caption': {'key': 'caption', 'type': 'str'},
        'query_parameter_name': {'key': 'queryParameterName', 'type': 'str'},
        'field_id': {'key': 'fieldId', 'type': 'int'},
        'data_field_id': {'key': 'dataFieldId', 'type': 'int'},
        'data_type': {'key': 'dataType', 'type': 'DataTypeResponse'},
        'operator': {'key': 'operator', 'type': 'str'},
        'value': {'key': 'value', 'type': 'str'},
        'required': {'key': 'required', 'type': 'bool'},
        'recommended': {'key': 'recommended', 'type': 'bool'},
    }

    def __init__(self, *, available_operator=None, caption: str=None, query_parameter_name: str=None, field_id: int=None, data_field_id: int=None, data_type=None, operator: str=None, value: str=None, required: bool=None, recommended: bool=None, **kwargs) -> None:
        super(FilterResponse, self).__init__(**kwargs)
        self.available_operator = available_operator
        self.caption = caption
        self.query_parameter_name = query_parameter_name
        self.field_id = field_id
        self.data_field_id = data_field_id
        self.data_type = data_type
        self.operator = operator
        self.value = value
        self.required = required
        self.recommended = recommended



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReadingCreate(Model):
    """ReadingCreate.

    All required parameters must be populated in order to send to Azure.

    :param channel_id:  Channel Identification
     The channel that receives the reading is determined by the following
     rules:
     Direct pointers to a channel
     If the channelId is supplied, then import to that channel.
     If the channelId is not supplied look at the channelImportId property,
     which indicates a specific channel.
     Inferred pointers to a channel
     If the channelId and channelImportId are not supplied, look at the
     meterImportId property, which indicates a meter.If that meter has one
     channel, import to that channel.
     If that meter has more than one channel, find the channel with the same
     observation type as the observationTypeCode property.If only one is found,
     import to that channel.
     If more than one channel is found based on observation type, find the
     channel with the same output unit as the unitCode property.If only one is
     found, import to that channel.
     If more than one channel is found based on unit, find the channel with the
     same channelIntervalInSeconds property. If only one is found, import to
     that channel. <span class='property-internal'>Topmost (Channel)</span>
    :type channel_id: int
    :param channel_import_id: The import identifier for the channel on which
     to create the reading. See the channelId property for more information
     <span class='property-internal'>Must be between 0 and 255
     characters</span>
    :type channel_import_id: str
    :param meter_import_id: The import identifier for the meter on which to
     create the reading. See the channelId property for more information <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type meter_import_id: str
    :param channel_interval_in_seconds:
    :type channel_interval_in_seconds: int
    :param observation_type_code: The observationType code of the reading. See
     the channelId property for more information <span
     class='property-internal'>Must be between 0 and 16 characters</span>
    :type observation_type_code: str
    :param unit_code: The unit code of the reading. See the channelId property
     for more information <span class='property-internal'>Must be between 0 and
     16 characters</span>
    :type unit_code: str
    :param readings: Required. array of readings <span
     class='property-internal'>Required</span>
    :type readings: list[~energycap.sdk.models.Reading]
    """

    _validation = {
        'channel_import_id': {'max_length': 255, 'min_length': 0},
        'meter_import_id': {'max_length': 255, 'min_length': 0},
        'observation_type_code': {'max_length': 16, 'min_length': 0},
        'unit_code': {'max_length': 16, 'min_length': 0},
        'readings': {'required': True},
    }

    _attribute_map = {
        'channel_id': {'key': 'channelId', 'type': 'int'},
        'channel_import_id': {'key': 'channelImportId', 'type': 'str'},
        'meter_import_id': {'key': 'meterImportId', 'type': 'str'},
        'channel_interval_in_seconds': {'key': 'channelIntervalInSeconds', 'type': 'int'},
        'observation_type_code': {'key': 'observationTypeCode', 'type': 'str'},
        'unit_code': {'key': 'unitCode', 'type': 'str'},
        'readings': {'key': 'readings', 'type': '[Reading]'},
    }

    def __init__(self, *, readings, channel_id: int=None, channel_import_id: str=None, meter_import_id: str=None, channel_interval_in_seconds: int=None, observation_type_code: str=None, unit_code: str=None, **kwargs) -> None:
        super(ReadingCreate, self).__init__(**kwargs)
        self.channel_id = channel_id
        self.channel_import_id = channel_import_id
        self.meter_import_id = meter_import_id
        self.channel_interval_in_seconds = channel_interval_in_seconds
        self.observation_type_code = observation_type_code
        self.unit_code = unit_code
        self.readings = readings



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class VendorUDFResponse(Model):
    """VendorUDFResponse.

    :param vendor_id: The vendor identifier
    :type vendor_id: int
    :param vendor_code: The vendor code
    :type vendor_code: str
    :param vendor_info: The vendor info
    :type vendor_info: str
    :param udfs: An array of user-defined fields (UDFs)
    :type udfs: list[~energycap.sdk.models.UDFFieldChild]
    """

    _attribute_map = {
        'vendor_id': {'key': 'vendorId', 'type': 'int'},
        'vendor_code': {'key': 'vendorCode', 'type': 'str'},
        'vendor_info': {'key': 'vendorInfo', 'type': 'str'},
        'udfs': {'key': 'udfs', 'type': '[UDFFieldChild]'},
    }

    def __init__(self, **kwargs):
        super(VendorUDFResponse, self).__init__(**kwargs)
        self.vendor_id = kwargs.get('vendor_id', None)
        self.vendor_code = kwargs.get('vendor_code', None)
        self.vendor_info = kwargs.get('vendor_info', None)
        self.udfs = kwargs.get('udfs', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SearchPlaceChildSearchPlaceChild(Model):
    """SearchPlaceChildSearchPlaceChild.

    All required parameters must be populated in order to send to Azure.

    :param place_id: The place identifier
    :type place_id: int
    :param place_code: Required. The place code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type place_code: str
    :param place_info: Required. The place info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type place_info: str
    :param place_type:
    :type place_type: ~energycap.sdk.models.PlaceTypeResponse
    :param address:
    :type address: ~energycap.sdk.models.AddressChild
    :param parent_path: The collection of places representing the path to its
     parent
    :type parent_path: list[~energycap.sdk.models.SearchParentPlaceChild]
    """

    _validation = {
        'place_code': {'required': True, 'max_length': 32, 'min_length': 0},
        'place_info': {'required': True, 'max_length': 50, 'min_length': 0},
    }

    _attribute_map = {
        'place_id': {'key': 'placeId', 'type': 'int'},
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'place_type': {'key': 'placeType', 'type': 'PlaceTypeResponse'},
        'address': {'key': 'address', 'type': 'AddressChild'},
        'parent_path': {'key': 'parentPath', 'type': '[SearchParentPlaceChild]'},
    }

    def __init__(self, **kwargs):
        super(SearchPlaceChildSearchPlaceChild, self).__init__(**kwargs)
        self.place_id = kwargs.get('place_id', None)
        self.place_code = kwargs.get('place_code', None)
        self.place_info = kwargs.get('place_info', None)
        self.place_type = kwargs.get('place_type', None)
        self.address = kwargs.get('address', None)
        self.parent_path = kwargs.get('parent_path', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountingSettingsResponse(Model):
    """AccountingSettingsResponse.

    :param fiscal_year_start_month: First month of fiscal year
     Value will be from 1-12
    :type fiscal_year_start_month: int
    :param fiscal_year_defined_at_year: Fiscal year reflects the calendar year
     in which it Begins or Ends
     Value will be one of "beginning", "ending"
    :type fiscal_year_defined_at_year: str
    :param calendarization_method: Calendarization method
     Value will be one of "monthly", "user-defined"
    :type calendarization_method: str
    :param account_periods: List of accounting period names
    :type account_periods: list[~energycap.sdk.models.AccountPeriodResponse]
    """

    _attribute_map = {
        'fiscal_year_start_month': {'key': 'fiscalYearStartMonth', 'type': 'int'},
        'fiscal_year_defined_at_year': {'key': 'fiscalYearDefinedAtYear', 'type': 'str'},
        'calendarization_method': {'key': 'calendarizationMethod', 'type': 'str'},
        'account_periods': {'key': 'accountPeriods', 'type': '[AccountPeriodResponse]'},
    }

    def __init__(self, **kwargs):
        super(AccountingSettingsResponse, self).__init__(**kwargs)
        self.fiscal_year_start_month = kwargs.get('fiscal_year_start_month', None)
        self.fiscal_year_defined_at_year = kwargs.get('fiscal_year_defined_at_year', None)
        self.calendarization_method = kwargs.get('calendarization_method', None)
        self.account_periods = kwargs.get('account_periods', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FixedUnitCostRequest(Model):
    """Fixed amount per unit to apply during bill calculation.

    All required parameters must be populated in order to send to Azure.

    :param unit_cost: Required. Fixed unit cost <span
     class='property-internal'>Required</span> <span class='property-info'>Max
     scale of 8</span>
    :type unit_cost: float
    :param unit_id: Required. Unit to which unit cost is applied <span
     class='property-internal'>Required</span>
    :type unit_id: int
    """

    _validation = {
        'unit_cost': {'required': True},
        'unit_id': {'required': True},
    }

    _attribute_map = {
        'unit_cost': {'key': 'unitCost', 'type': 'float'},
        'unit_id': {'key': 'unitId', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(FixedUnitCostRequest, self).__init__(**kwargs)
        self.unit_cost = kwargs.get('unit_cost', None)
        self.unit_id = kwargs.get('unit_id', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebackProcessorSettingsForAggregations(Model):
    """ChargebackProcessorSettingsForAggregations.

    :param billing_period: End period of Billing Period range to be processed
    :type billing_period: int
    :param note: Optional note/comment <span class='property-internal'>Must be
     between 0 and 255 characters</span>
    :type note: str
    :param batch_settings:
    :type batch_settings: ~energycap.sdk.models.BatchCreate
    """

    _validation = {
        'note': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'note': {'key': 'note', 'type': 'str'},
        'batch_settings': {'key': 'batchSettings', 'type': 'BatchCreate'},
    }

    def __init__(self, **kwargs):
        super(ChargebackProcessorSettingsForAggregations, self).__init__(**kwargs)
        self.billing_period = kwargs.get('billing_period', None)
        self.note = kwargs.get('note', None)
        self.batch_settings = kwargs.get('batch_settings', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GHGFactorsResponse(Model):
    """GHGFactorsResponse.

    :param ghg_factor_id: The identifier for ghg factor
    :type ghg_factor_id: int
    :param ghg_factor: The ghg factor
    :type ghg_factor: float
    :param ghg_co2_factor: The ghg CO2 factor
    :type ghg_co2_factor: float
    :param start_date: The start date
    :type start_date: datetime
    :param end_date: The end date
    :type end_date: datetime
    :param description: The description
    :type description: str
    :param memo: The notes
    :type memo: str
    :param ghg_type:
    :type ghg_type: ~energycap.sdk.models.GHGTypeChild
    :param commodity_unit:
    :type commodity_unit: ~energycap.sdk.models.UnitChild
    :param ghg_unit:
    :type ghg_unit: ~energycap.sdk.models.UnitChild
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    """

    _attribute_map = {
        'ghg_factor_id': {'key': 'ghgFactorId', 'type': 'int'},
        'ghg_factor': {'key': 'ghgFactor', 'type': 'float'},
        'ghg_co2_factor': {'key': 'ghgCO2Factor', 'type': 'float'},
        'start_date': {'key': 'startDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'description': {'key': 'description', 'type': 'str'},
        'memo': {'key': 'memo', 'type': 'str'},
        'ghg_type': {'key': 'ghgType', 'type': 'GHGTypeChild'},
        'commodity_unit': {'key': 'commodityUnit', 'type': 'UnitChild'},
        'ghg_unit': {'key': 'ghgUnit', 'type': 'UnitChild'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
    }

    def __init__(self, *, ghg_factor_id: int=None, ghg_factor: float=None, ghg_co2_factor: float=None, start_date=None, end_date=None, description: str=None, memo: str=None, ghg_type=None, commodity_unit=None, ghg_unit=None, commodity=None, **kwargs) -> None:
        super(GHGFactorsResponse, self).__init__(**kwargs)
        self.ghg_factor_id = ghg_factor_id
        self.ghg_factor = ghg_factor
        self.ghg_co2_factor = ghg_co2_factor
        self.start_date = start_date
        self.end_date = end_date
        self.description = description
        self.memo = memo
        self.ghg_type = ghg_type
        self.commodity_unit = commodity_unit
        self.ghg_unit = ghg_unit
        self.commodity = commodity



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BenchmarkWithUsedCountResponse(Model):
    """BenchmarkWithUsedCountResponse.

    :param used_count: Number of times benchmark is used
    :type used_count: int
    :param benchmark_indicator: Indicator for which benchmark factor
    :type benchmark_indicator: int
    :param benchmark_info: benchmark info
    :type benchmark_info: str
    :param benchmark_category:
    :type benchmark_category: ~energycap.sdk.models.BenchmarkCategoryResponse
    """

    _attribute_map = {
        'used_count': {'key': 'usedCount', 'type': 'int'},
        'benchmark_indicator': {'key': 'benchmarkIndicator', 'type': 'int'},
        'benchmark_info': {'key': 'benchmarkInfo', 'type': 'str'},
        'benchmark_category': {'key': 'benchmarkCategory', 'type': 'BenchmarkCategoryResponse'},
    }

    def __init__(self, **kwargs):
        super(BenchmarkWithUsedCountResponse, self).__init__(**kwargs)
        self.used_count = kwargs.get('used_count', None)
        self.benchmark_indicator = kwargs.get('benchmark_indicator', None)
        self.benchmark_info = kwargs.get('benchmark_info', None)
        self.benchmark_category = kwargs.get('benchmark_category', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GLSubcodeRequest(Model):
    """GLSubcodeRequest.

    All required parameters must be populated in order to send to Azure.

    :param sub_code_index: Required. Index of this subcode (1-20) <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 1 and 20</span>
    :type sub_code_index: int
    :param sub_code_name: Required. Name for this SubCode <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type sub_code_name: str
    :param sub_code_type: Required. SubCodeType - should be "list"(fixed=1 in
     DB) or "text" (fixed=0 in DB) <span
     class='property-internal'>Required</span> <span
     class='property-internal'>One of list, text </span>
    :type sub_code_type: str
    :param sub_code_values: An array of pick list values when this subcode is
     a "list" <span class='property-internal'>Required when subCodeType is set
     to list</span>
    :type sub_code_values: list[str]
    """

    _validation = {
        'sub_code_index': {'required': True, 'maximum': 20, 'minimum': 1},
        'sub_code_name': {'required': True, 'max_length': 32, 'min_length': 0},
        'sub_code_type': {'required': True},
    }

    _attribute_map = {
        'sub_code_index': {'key': 'subCodeIndex', 'type': 'int'},
        'sub_code_name': {'key': 'subCodeName', 'type': 'str'},
        'sub_code_type': {'key': 'subCodeType', 'type': 'str'},
        'sub_code_values': {'key': 'subCodeValues', 'type': '[str]'},
    }

    def __init__(self, **kwargs):
        super(GLSubcodeRequest, self).__init__(**kwargs)
        self.sub_code_index = kwargs.get('sub_code_index', None)
        self.sub_code_name = kwargs.get('sub_code_name', None)
        self.sub_code_type = kwargs.get('sub_code_type', None)
        self.sub_code_values = kwargs.get('sub_code_values', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceSubmissionTypeRequest(Model):
    """PlaceSubmissionTypeRequest.

    :param submission_type: The submission type to apply <span
     class='property-internal'>One of Automatic, Manual </span> <span
     class='property-internal'>Required (defined)</span>
    :type submission_type: str
    :param place_ids: The list of places whose submission types will be
     updated <span class='property-internal'>Cannot be Empty</span> <span
     class='property-internal'>Required (defined)</span>
    :type place_ids: list[int]
    """

    _attribute_map = {
        'submission_type': {'key': 'submissionType', 'type': 'str'},
        'place_ids': {'key': 'placeIds', 'type': '[int]'},
    }

    def __init__(self, *, submission_type: str=None, place_ids=None, **kwargs) -> None:
        super(PlaceSubmissionTypeRequest, self).__init__(**kwargs)
        self.submission_type = submission_type
        self.place_ids = place_ids



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TimeZoneChild(Model):
    """TimeZoneChild.

    :param time_zone_id:
    :type time_zone_id: int
    :param time_zone_code:
    :type time_zone_code: str
    :param time_zone_info:
    :type time_zone_info: str
    """

    _attribute_map = {
        'time_zone_id': {'key': 'timeZoneId', 'type': 'int'},
        'time_zone_code': {'key': 'timeZoneCode', 'type': 'str'},
        'time_zone_info': {'key': 'timeZoneInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(TimeZoneChild, self).__init__(**kwargs)
        self.time_zone_id = kwargs.get('time_zone_id', None)
        self.time_zone_code = kwargs.get('time_zone_code', None)
        self.time_zone_info = kwargs.get('time_zone_info', None)
